@@ -5,29 +5,27 @@ define([
     , 'nbextensions/visualpython/src/common/StringBuilder'
 
     , '../../api.js'    
-    , '../../config.js'
     , '../../constData.js'
-    , '../../blockRenderer.js'
     , '../base/index.js'
 ], function ( $, vpCommon, vpConst, sb, 
             //   block
               api
-              , config
               , constData
-              , blockRenderer
               , baseComponent ) {
 
 
     const { MakeOptionContainer } = baseComponent;
-    var InitElseBlockOption = function(thatBlock, optionPageSelector) {
+    var InitElseBlockOption = function(thisBlock, optionPageSelector) {
         var renderThisComponent = function() {
-            var elseBlockOption = MakeOptionContainer();
+            var elseBlockOption = MakeOptionContainer(thisBlock);
             elseBlockOption.append('<div>(N/A)</div>');
 
             /**block option 탭에 렌더링된 dom객체 생성 */
             $(optionPageSelector).append(elseBlockOption);
+            
+            return elseBlockOption;
         }
-        renderThisComponent();
+        return renderThisComponent();
     }
 
     return InitElseBlockOption;
