@@ -8,84 +8,22 @@ define([
     , 'nbextensions/visualpython/src/common/component/vpTableLayoutHorizontalSimple'
 
     , '../../api.js'    
-    , '../../config.js'
     , '../../constData.js'
-    , '../../blockRenderer.js'
     , '../base/index.js'
 
 ], function ( $, vpCommon, vpConst, sb, vpSuggestInputText, vpTableLayoutVerticalSimple, vpTableLayoutHorizontalSimple
 
               , api
-              , config
               , constData
-              , blockRenderer
               , baseComponent ) {
 
-    const { ChangeOldToNewState
-        , FindStateValue
-
-        , CreateOneArrayValueAndGet
-        , UpdateOneArrayValueAndGet
-        , DeleteOneArrayValueAndGet
-
-        , DestructureFromBlockArray
-
-        , MakeFirstCharToUpperCase
-        , MapTypeToName
-        , RemoveSomeBlockAndGetBlockList
-        , ShuffleArray
-        , GetImageUrl
-        , ControlToggleInput } = api;
-
-    const { PROCESS_MODE } = config;
-
-    const { RenderBlockMainDom
-            , RenderBlockLeftHolderDom
-            , RenderBlockMainInnerDom
-            , RenderBlockMainHeaderDom
-
-            , RenderOptionPageContainer
-            , RenderOptionPageContainerInner
-            , RenderOptionPageInnerDom
-            , RenderOptionPageName
-            , RenderOptionTitle
-
-            , RenderInParamContainer
-            , RenderInParamDom
-            , RenderDefParamDom
-            , RenderBottomOptionTitle
-            , RenderDefaultOrDetailButton
-            , RenderInputRequiredColor
-            , RenderSelectRequiredColor
-            , RenderDeleteButton
-            , RenderSmallPlusDeleteButton
-
-
-
-            , RenderDefaultImportDom
-            , RenderCustomImportDom
-            , RenderIfElifOrExceptContainer
-            , RenderDefParamOrIfElifConditionPlusButton
-            , RenderDefaultOrCustomImportContainer
-
-            , RenderRunBlockButton
-            , RenderDeleteBlockButton
-            , RenderFocusedPage
-            
-            , RenderDomContainer
-            , RenderPropertyDom
-            , RenderPropertyDomFromDef
-
-            , RenderClassParentDom
-            , RenderCodeBlockInputRequired
-
-            , RenderHTMLDomColor
-
-            , GenerateClassInParamList
-            , GenerateDefInParamList
-            , GenerateReturnOutParamList
+    const { CreateOneArrayValueAndGet
+            , UpdateOneArrayValueAndGet
+            , DeleteOneArrayValueAndGet
+        
             , GenerateIfConditionList
-            , GenerateForParam } = blockRenderer;
+            , RenderInputRequiredColor
+            , RenderSelectRequiredColor } = api;
 
     const { BLOCK_DIRECTION
             , BLOCK_CODELINE_BTN_TYPE
@@ -95,7 +33,7 @@ define([
             , IF_BLOCK_SELECT_VALUE_ARG_TYPE
 
             , STR_COLON_SELECTED
-            , STR_NULL
+            , STR_EMPTY
             , STR_FOR
             , STR_INPUT
             , STR_SELECTED 
@@ -163,33 +101,88 @@ define([
             , MakeOptionDeleteButton
             , MakeOptionPlusButton
             , MakeVpSuggestInputText_apiblock
-            , MakeOptionInput } = baseComponent;
+            , MakeOptionInput
+            , MakeOptionSelectBox } = baseComponent;
 
-            var InitIfBlockOption = function(thatBlock, optionPageSelector) {
-                var uuid = thatBlock.getUUID();
-                var blockContainerThis = thatBlock.getBlockContainerThis();
-                var ifConditionListState = thatBlock.getState(STATE_ifConditionList);  
+            var InitIfBlockOption = function(thisBlock, optionPageSelector) {
+                var uuid = thisBlock.getUUID();
+                var blockContainerThis = thisBlock.getBlockContainerThis();
+                var ifConditionListState = thisBlock.getState(STATE_ifConditionList);  
            
                 /** --------------------------------- If Option 이벤트 함수 바인딩 ---------------------------------- */           
         
                 /** if 변경 이벤트 함수 바인딩 */
                 ifConditionListState.forEach( ( condition, index ) => {
-                    var uuid = thatBlock.getUUID();
+                    var uuid = thisBlock.getUUID();
                     const { conditionType } = condition;
-        
+    
+   /**
+                         * @event_function
+                         * iF arg2 선택 변경 
+                         */
+                        $(document).off(STR_CHANGE, VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_IF_ARG_2 + index + uuid);
+                        $(document).on(STR_CHANGE, VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_IF_ARG_2 + index + uuid, function(event) {
+                            // RenderInputRequiredColor(this);
+                            var ifConditionListState = thisBlock.getState(STATE_ifConditionList);
+                            var ifConditionState = ifConditionListState[index];
+                            var selectedValue = $(STR_COLON_SELECTED, this).val();
+                            if (selectedValue == 'none') {
+                                selectedValue = STR_EMPTY;
+                            }
+                            var updatedValue = {
+                                ...ifConditionState
+                                ,arg2: selectedValue
+                            }
+                            ifConditionListState = UpdateOneArrayValueAndGet(ifConditionListState, index, updatedValue);
+                            thisBlock.setState({
+                                ifConditionList: ifConditionListState
+                            });
+
+                            var ifConditionCode = GenerateIfConditionList(thisBlock);
+                            thisBlock.writeCode(ifConditionCode);
+                            blockContainerThis.renderBlockOptionTab();
+                            event.stopPropagation();
+                        });
+
+                        /**
+                         * @event_function
+                         * iF arg4 선택 변경 
+                         */
+                        $(document).off(STR_CHANGE, VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_IF_ARG_4 + index + uuid);
+                        $(document).on(STR_CHANGE, VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_IF_ARG_4 + index + uuid, function(event) {
+                            // RenderInputRequiredColor(this);
+                            var ifConditionListState = thisBlock.getState(STATE_ifConditionList);
+                            var ifConditionState = ifConditionListState[index];
+                            var selectedValue = $(STR_COLON_SELECTED, this).val();
+                            if (selectedValue == 'none') {
+                                selectedValue = STR_EMPTY;
+                            }
+                            var updatedValue = {
+                                ...ifConditionState
+                                ,arg4: selectedValue
+                            }
+                            ifConditionListState = UpdateOneArrayValueAndGet(ifConditionListState, index, updatedValue);
+                            thisBlock.setState({
+                                ifConditionList: ifConditionListState
+                            });
+
+                            var ifConditionCode = GenerateIfConditionList(thisBlock);
+                            thisBlock.writeCode(ifConditionCode);
+                            
+                            blockContainerThis.renderBlockOptionTab();
+                            event.stopPropagation();
+                        });
                     // IF_BLOCK_CONDITION_TYPE
                     if (conditionType == IF_BLOCK_CONDITION_TYPE.ARG) {
                         for (var k = 1; k < 7; k++) {
                             ((i) => {
             
                                 /** arg1 arg2 arg3 arg4 arg5 arg6 */
-                                /** If arg input 변경 이벤트 함수 바인딩 */
+                                /** If arg input 입력 변경 이벤트 함수 바인딩 */
                                     $(document).off(STR_CHANGE_KEYUP_PASTE, VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_IF_ARG +i+ index + uuid);
                                     $(document).on(STR_CHANGE_KEYUP_PASTE, VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_IF_ARG +i+ index + uuid, function(event) {
-                             
-                             
-                               
-                                        var ifConditionListState = thatBlock.getState(STATE_ifConditionList);
+                            
+                                        var ifConditionListState = thisBlock.getState(STATE_ifConditionList);
                                         var ifConditionState = ifConditionListState[index];
                                         var inputValue = $(this).val();
             
@@ -213,11 +206,12 @@ define([
                                             }
                                             // RenderInputRequiredColor(this);
                                         }  else if (i == 4) {
+                                            
                                             updatedValue = {
                                                 ...ifConditionState
                                                 ,arg4: inputValue
                                             }
-                                            if (inputValue == 'none' || inputValue == STR_NULL) {
+                                            if (inputValue == '') {
                                                 $(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_IF_ARG_4 + index + uuid).addClass(VP_CLASS_STYLE_BGCOLOR_C4C4C4);
                                                 $(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_IF_ARG_5 + index + uuid).addClass(VP_CLASS_STYLE_BGCOLOR_C4C4C4);
                                                 $(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_IF_ARG_5 + index + uuid).attr("disabled", true);
@@ -240,12 +234,13 @@ define([
                                         }
             
                                         ifConditionListState = UpdateOneArrayValueAndGet(ifConditionListState, index, updatedValue);
-                                        thatBlock.setState({
+                                        thisBlock.setState({
                                             ifConditionList: ifConditionListState
                                         });
-                                        var ifConditionCode = GenerateIfConditionList(thatBlock,BLOCK_CODELINE_TYPE.IF);
-                                        $(`.vp-block-header-${thatBlock.getUUID()}`).html(ifConditionCode);
-                                    
+
+                                        var ifConditionCode = GenerateIfConditionList(thisBlock,BLOCK_CODELINE_TYPE.IF);
+                                        thisBlock.writeCode(ifConditionCode);
+
                                         event.stopPropagation();
                                     });
                 
@@ -259,7 +254,7 @@ define([
                  
                             // RenderInputRequiredColor(this);
                    
-                            var ifConditionListState = thatBlock.getState(STATE_ifConditionList);
+                            var ifConditionListState = thisBlock.getState(STATE_ifConditionList);
                             var ifConditionState = ifConditionListState[index];
                             var inputValue = $(this).val();
         
@@ -270,12 +265,12 @@ define([
                        
         
                             ifConditionListState = UpdateOneArrayValueAndGet(ifConditionListState, index, updatedValue);
-                            thatBlock.setState({
+                            thisBlock.setState({
                                 ifConditionList: ifConditionListState
                             });
-                            var ifConditionCode = GenerateIfConditionList(thatBlock,BLOCK_CODELINE_TYPE.IF);
-                            $(`.vp-block-header-${thatBlock.getUUID()}`).html(ifConditionCode);
-                        
+
+                            var ifConditionCode = GenerateIfConditionList(thisBlock,BLOCK_CODELINE_TYPE.IF);
+                            thisBlock.writeCode(ifConditionCode);
                             event.stopPropagation();
                         });
         
@@ -285,7 +280,7 @@ define([
                  
                             // RenderInputRequiredColor(this);
                    
-                            var ifConditionListState = thatBlock.getState(STATE_ifConditionList);
+                            var ifConditionListState = thisBlock.getState(STATE_ifConditionList);
                             var ifConditionState = ifConditionListState[index];
                             var inputValue = $(this).val();
         
@@ -295,11 +290,12 @@ define([
                             }
         
                             ifConditionListState = UpdateOneArrayValueAndGet(ifConditionListState, index, updatedValue);
-                            thatBlock.setState({
+                            thisBlock.setState({
                                 ifConditionList: ifConditionListState
                             });
-                            var ifConditionCode = GenerateIfConditionList(thatBlock,BLOCK_CODELINE_TYPE.IF);
-                            $(`.vp-block-header-${thatBlock.getUUID()}`).html(ifConditionCode);
+
+                            var ifConditionCode = GenerateIfConditionList(thisBlock,BLOCK_CODELINE_TYPE.IF);
+                            thisBlock.writeCode(ifConditionCode);
                         
                             event.stopPropagation();
                         });
@@ -308,7 +304,7 @@ define([
                     /** 삭제 if condition */
                     $(document).off(STR_CLICK, vpCommon.wrapSelector(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_IF_DELETE + index + uuid));
                     $(document).on(STR_CLICK, vpCommon.wrapSelector(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_IF_DELETE + index + uuid), function(event) {
-                        var ifConditionListState = thatBlock.getState(STATE_ifConditionList);
+                        var ifConditionListState = thisBlock.getState(STATE_ifConditionList);
         
                         if (ifConditionListState.length == 1) {
                             return;
@@ -316,11 +312,11 @@ define([
                         
                         ifConditionListState = DeleteOneArrayValueAndGet(ifConditionListState, index);
         
-                        thatBlock.setState({
+                        thisBlock.setState({
                             ifConditionList: ifConditionListState
                         });
-                        var ifConditionCode = GenerateIfConditionList(thatBlock, BLOCK_CODELINE_TYPE.IF);
-                        $(`.vp-block-header-${thatBlock.getUUID()}`).html(ifConditionCode);
+                        var ifConditionCode = GenerateIfConditionList(thisBlock, BLOCK_CODELINE_TYPE.IF);
+                        thisBlock.writeCode(ifConditionCode);
         
                         blockContainerThis.renderBlockOptionTab();
         
@@ -332,24 +328,23 @@ define([
                 $(document).off(STR_CLICK, vpCommon.wrapSelector(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_IF_PLUS + uuid));
                 $(document).on(STR_CLICK, vpCommon.wrapSelector(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_IF_PLUS + uuid), function(event) {
         
-                    var ifConditionListState = thatBlock.getState(STATE_ifConditionList);
-                    thatBlock.addVariableIndex();
-                    // var variableIndex = thatBlock.getVariableIndex();
+                    var ifConditionListState = thisBlock.getState(STATE_ifConditionList);
+                    thisBlock.addVariableIndex();
                     var newCondition = {
                         arg1: ''
                         , arg2: ''
                         , arg3: ''
-                        , arg4: 'none'
+                        , arg4: ''
                         , arg5: ''
                         , arg6: ''
                         , conditionType: IF_BLOCK_CONDITION_TYPE.ARG
                     }
                     ifConditionListState = CreateOneArrayValueAndGet(ifConditionListState, ifConditionListState.length, newCondition);
-                    thatBlock.setState({
+                    thisBlock.setState({
                         ifConditionList: ifConditionListState
                     });
-                    var ifConditionCode = GenerateIfConditionList(thatBlock, BLOCK_CODELINE_TYPE.IF);
-                    $(`.vp-block-header-${thatBlock.getUUID()}`).html(ifConditionCode);
+                    var ifConditionCode = GenerateIfConditionList(thisBlock, BLOCK_CODELINE_TYPE.IF);
+                    thisBlock.writeCode(ifConditionCode);
                     
                     blockContainerThis.renderBlockOptionTab();
                     event.stopPropagation();
@@ -359,8 +354,8 @@ define([
                 $(document).off(STR_CLICK, vpCommon.wrapSelector(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_IF_PLUS_USER_INPUT + uuid));
                 $(document).on(STR_CLICK, vpCommon.wrapSelector(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_IF_PLUS_USER_INPUT + uuid), function(event) {
         
-                    var ifConditionListState = thatBlock.getState(STATE_ifConditionList);
-                    thatBlock.addVariableIndex();
+                    var ifConditionListState = thisBlock.getState(STATE_ifConditionList);
+                    thisBlock.addVariableIndex();
                 
                     var newCondition = {
                         codeLine: ''
@@ -368,11 +363,12 @@ define([
                         , conditionType: IF_BLOCK_CONDITION_TYPE.USER_INPUT
                     }
                     ifConditionListState = CreateOneArrayValueAndGet(ifConditionListState, ifConditionListState.length, newCondition);
-                    thatBlock.setState({
+                    thisBlock.setState({
                         ifConditionList: ifConditionListState
                     });
-                    var ifConditionCode = GenerateIfConditionList(thatBlock, BLOCK_CODELINE_TYPE.IF);
-                    $(`.vp-block-header-${thatBlock.getUUID()}`).html(ifConditionCode);
+
+                    var ifConditionCode = GenerateIfConditionList(thisBlock, BLOCK_CODELINE_TYPE.IF);
+                    thisBlock.writeCode(ifConditionCode);
                     
                     blockContainerThis.renderBlockOptionTab();
                     event.stopPropagation();
@@ -380,7 +376,7 @@ define([
         
                 /** arg1, arg2, arg3, arg4, arg5, arg6 select 변경 if condition */
                 var bindSelectValueEventFunc_if = function(selectedValue, index, type) {
-                    var ifConditionListState = thatBlock.getState(STATE_ifConditionList);
+                    var ifConditionListState = thisBlock.getState(STATE_ifConditionList);
                     var ifConditionState = ifConditionListState[index];
                     var updatedValue;
                     if (type == IF_BLOCK_SELECT_VALUE_ARG_TYPE.ARG1) {
@@ -390,6 +386,9 @@ define([
                         }
                         // RenderSelectRequiredColor(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_IF_ARG_1 + index + uuid, selectedValue);
                     } else if (type == IF_BLOCK_SELECT_VALUE_ARG_TYPE.ARG2) {
+                        if (selectedValue == 'none') {
+                            selectedValue = STR_EMPTY;
+                        }
                         updatedValue = {
                             ...ifConditionState
                             , arg2: selectedValue 
@@ -402,12 +401,15 @@ define([
                         }
                         // RenderSelectRequiredColor(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_IF_ARG_3 + index + uuid, selectedValue);
                     } else if (type == IF_BLOCK_SELECT_VALUE_ARG_TYPE.ARG4) {
+               
+                        if (selectedValue == 'none') {
+                            selectedValue = STR_EMPTY;
+                        }
                         updatedValue = {
                             ...ifConditionState
                             , arg4: selectedValue 
                         }
-        
-                        if (selectedValue == 'none' || selectedValue == '') {
+                        if (selectedValue == STR_EMPTY) {
                             $(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_IF_ARG_4 + index + uuid).addClass(VP_CLASS_STYLE_BGCOLOR_C4C4C4);
                             $(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_IF_ARG_5 + index + uuid).addClass(VP_CLASS_STYLE_BGCOLOR_C4C4C4);
                             $(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_IF_ARG_5 + index + uuid).attr(STR_DISABLED, true);
@@ -430,42 +432,25 @@ define([
                         // RenderSelectRequiredColor(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_IF_ARG_6 + index + uuid, selectedValue);
                     }
                     ifConditionListState = UpdateOneArrayValueAndGet(ifConditionListState, index, updatedValue);
-                    thatBlock.setState({
+                    thisBlock.setState({
                         ifConditionList: ifConditionListState
                     });
-                    var ifConditionCode = GenerateIfConditionList(thatBlock, BLOCK_CODELINE_TYPE.IF);
-                    $(`.vp-block-header-${thatBlock.getUUID()}`).html(ifConditionCode);
-        
-        
-                    // blockContainerThis.renderBlockOptionTab();
+                    var ifConditionCode = GenerateIfConditionList(thisBlock, BLOCK_CODELINE_TYPE.IF);
+                    thisBlock.writeCode(ifConditionCode);
+   
                 }
         
-                /** --------------------------------- Else Option 이벤트 함수 바인딩 ---------------------------------- */  
-                /** Else block 생성, 삭제 이벤트 함수 바인딩 */
-                // blockContainerThis.bindElseBlockEvent(thatBlock, BLOCK_CODELINE_TYPE.ELSE);
-        
-        
-        
-        
-        
-        
-        
-        
-        
-        
-        
-        
                 /** If option 렌더링 */
                 var renderThisComponent = function() {
                     // console.log('if render');
-                    var optionContainerDom = MakeOptionContainer();
+                    var optionContainerDom = MakeOptionContainer(thisBlock);
                     /* --------------------------- if ----------------------------- */
                     var loadedVariableNameList = blockContainerThis.getKernelLoadedVariableNameList();
-                    // var variableIndex = thatBlock.getVariableIndex();
         
-                    var ifConditionListState = thatBlock.getState(STATE_ifConditionList);   
+                    var ifConditionListState = thisBlock.getState(STATE_ifConditionList);   
                     ifConditionListState.forEach( (condition, index) => {
-             
+                     
+
                         const { conditionType } = condition; 
              
                         var sbCondition = new sb.StringBuilder();
@@ -490,17 +475,21 @@ define([
                                                                                         bindSelectValueEventFunc_if(selectedValue, 
                                                                                                                     index,
                                                                                                                     IF_BLOCK_SELECT_VALUE_ARG_TYPE.ARG1);
-                                                                                        });   
-                            var suggestInputArg2 =  MakeVpSuggestInputText_apiblock(VP_ID_APIBLOCK_OPTION_IF_ARG_2 + index + uuid
-                                                                                    , arg2
-                                                                                    , COMPARISON_OPERATOR_IF_ARG2
-                                                                                    , VP_CLASS_STYLE_WIDTH_15PERCENT
-                                                                                    , STR_OPERATOR
-                                                                                    , function(selectedValue) {
-                                                                                    bindSelectValueEventFunc_if(selectedValue, 
-                                                                                                                index,
-                                                                                                                IF_BLOCK_SELECT_VALUE_ARG_TYPE.ARG2);
-                                                                                    });                                                               
+                                                                                        });  
+                                                                                                                          
+                            var sbIfArg2;
+                                sbIfArg2 = MakeVpSuggestInputText_apiblock(VP_ID_APIBLOCK_OPTION_IF_ARG_2 + index + uuid
+                                                , arg2
+                                                , COMPARISON_OPERATOR_IF_ARG2
+                                                , VP_CLASS_STYLE_WIDTH_15PERCENT
+                                                , STR_OPERATOR
+                                                , function(selectedValue) {
+                                                bindSelectValueEventFunc_if(selectedValue, 
+                                                                            index,
+                                                                            IF_BLOCK_SELECT_VALUE_ARG_TYPE.ARG2);
+                                                });     
+
+                                                              
                             var suggestInputArg3 =  MakeVpSuggestInputText_apiblock(VP_ID_APIBLOCK_OPTION_IF_ARG_3 + index + uuid
                                                                                     , arg3
                                                                                     , loadedVariableNameList_arg3
@@ -511,16 +500,18 @@ define([
                                                                                                                     index,
                                                                                                                     IF_BLOCK_SELECT_VALUE_ARG_TYPE.ARG3);
                                                                                         });   
-                            var suggestInputArg4 =  MakeVpSuggestInputText_apiblock(VP_ID_APIBLOCK_OPTION_IF_ARG_4 + index + uuid
-                                                                                    , arg4
-                                                                                    , COMPARISON_OPERATOR_IF_ARG4
-                                                                                    , VP_CLASS_STYLE_WIDTH_15PERCENT
-                                                                                    , STR_OPERATOR
-                                                                                    , function(selectedValue) {
-                                                                                        bindSelectValueEventFunc_if(selectedValue, 
-                                                                                            index,
-                                                                                            IF_BLOCK_SELECT_VALUE_ARG_TYPE.ARG4);
-                                                                                    });    
+                            var sbIfArg4;
+                            sbIfArg4 =  MakeVpSuggestInputText_apiblock(VP_ID_APIBLOCK_OPTION_IF_ARG_4 + index + uuid
+                                    , arg4
+                                    , COMPARISON_OPERATOR_IF_ARG4
+                                    , VP_CLASS_STYLE_WIDTH_15PERCENT
+                                    , STR_OPERATOR
+                                    , function(selectedValue) {
+                                        bindSelectValueEventFunc_if(selectedValue, 
+                                            index,
+                                            IF_BLOCK_SELECT_VALUE_ARG_TYPE.ARG4);
+                            });    
+
                             var suggestInputArg5 =  MakeVpSuggestInputText_apiblock(VP_ID_APIBLOCK_OPTION_IF_ARG_5 + index + uuid
                                                                                     , arg5
                                                                                     , loadedVariableNameList_arg5
@@ -543,9 +534,9 @@ define([
                                                                                                 IF_BLOCK_SELECT_VALUE_ARG_TYPE.ARG6);
                                                                                     });      
                             sbConditionLeft.appendLine(suggestInputArg1);
-                            sbConditionLeft.appendLine(suggestInputArg2);
+                            sbConditionLeft.appendLine(sbIfArg2);
                             sbConditionLeft.appendLine(suggestInputArg3);
-                            sbConditionLeft.appendLine(suggestInputArg4);
+                            sbConditionLeft.appendLine(sbIfArg4);
                             sbConditionLeft.appendLine(suggestInputArg5);
                             sbConditionLeft.appendLine("</div>");
         
@@ -558,6 +549,7 @@ define([
                             sbCondition.appendLine("</div>");
                         } else {
                             const { arg6, codeLine } = condition;
+              
                             var sbOptionInput = MakeOptionInput(VP_ID_APIBLOCK_OPTION_IF_USER_INPUT + index + uuid
                                                                 , VP_CLASS_STYLE_WIDTH_100PERCENT
                                                                 , codeLine
@@ -615,29 +607,33 @@ define([
                      *  3. none opacity 0 설정
                      *  4. 입력되지 않은 값 border alert 처리
                      *  */
+                    var ifConditionListState = thisBlock.getState(STATE_ifConditionList);   
                     ifConditionListState.forEach( (condition,index) => {
                         const { arg1, arg2, arg3, arg4, arg5, arg6 } = condition;
         
                         $(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_IF_ARG_1 + index + uuid).val(arg1);
-                        $(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_IF_ARG_2 + index + uuid).val(arg2);
+                  
                         $(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_IF_ARG_3 + index + uuid).val(arg3);
-                        $(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_IF_ARG_4 + index + uuid).val(arg4);
+               
                         $(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_IF_ARG_5 + index + uuid).val(arg5);
-                        // var isArg5Disabled = false;   
-                        // isArg5Disabled = true;
-                        if (arg4 == 'none' || arg4 == STR_NULL) {
+                        // if (arg2 == 'none') {
+                        //     $(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_IF_ARG_2 + index + uuid).val(STR_EMPTY);
+                        // } else {
+                        //     $(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_IF_ARG_2 + index + uuid).val(arg2);
+                        // }
+                        $(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_IF_ARG_2 + index + uuid).val(arg2);
+                        if (arg4 == '') {
+                            $(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_IF_ARG_4 + index + uuid).val(STR_EMPTY);
                             $(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_IF_ARG_4 + index + uuid).addClass(VP_CLASS_STYLE_BGCOLOR_C4C4C4);
                             $(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_IF_ARG_5 + index + uuid).attr(STR_DISABLED, true);
                             $(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_IF_ARG_5 + index + uuid).addClass(VP_CLASS_STYLE_BGCOLOR_C4C4C4);
                         } else {
+                            $(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_IF_ARG_4 + index + uuid).val(arg4);
                             $(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_IF_ARG_4 + index + uuid).removeClass(VP_CLASS_STYLE_BGCOLOR_C4C4C4);
                             $(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_IF_ARG_5 + index + uuid).attr(STR_DISABLED, false);
                             $(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_IF_ARG_5 + index + uuid).removeClass(VP_CLASS_STYLE_BGCOLOR_C4C4C4);
                         }     
-        
-                        /** arg6 isDisabled 체크 */
-                        // var isArg6Disabled = false;
-                        // isArg6Disabled = true;
+      
                         if ( ifConditionListState.length -1 == index ) {
                             $(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_IF_ARG_6 + index + uuid).addClass(VP_CLASS_STYLE_OPACITY_0);
                         } else {
@@ -652,9 +648,11 @@ define([
         
                         // RenderInputRequiredColor(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_IF_USER_INPUT + index + uuid);
                     });
+
+                    return optionContainerDom;
                 }
         
-                renderThisComponent();
+                return renderThisComponent();
             }
         
             return InitIfBlockOption;
