@@ -6,35 +6,18 @@ define([
     , 'nbextensions/visualpython/src/common/component/vpTableLayoutVerticalSimple'
 
     , '../../api.js'    
-    , '../../config.js'
     , '../../constData.js'
-    , '../../blockRenderer.js'
     , '../base/index.js'
 
 ], function ( $, vpCommon, vpConst, sb, vpTableLayoutVerticalSimple, 
-              api, config, constData, 
-              blockRenderer, baseComponent ) {
+              api,constData, baseComponent ) {
 
-    const { ChangeOldToNewState
-            , FindStateValue
-
-            , CreateOneArrayValueAndGet
+    const { CreateOneArrayValueAndGet
             , UpdateOneArrayValueAndGet
             , DeleteOneArrayValueAndGet
 
-            , DestructureFromBlockArray
-
-            , MakeFirstCharToUpperCase
-            , MapTypeToName
-            , RemoveSomeBlockAndGetBlockList
-            , ShuffleArray
-            , GetImageUrl
-            , ControlToggleInput } = api;
-
-    const { PROCESS_MODE } = config;
-
-    const { GenerateListforConditionList
-            ,GenerateForParam  } = blockRenderer;
+            , GenerateListforConditionList
+            , GenerateForParam  } = api;
 
     const { BLOCK_CODELINE_BTN_TYPE
                 , BLOCK_CODELINE_TYPE
@@ -107,7 +90,7 @@ define([
                 
                 , VP_CLASS_STYLE_BGCOLOR_C4C4C4
 
-                , STR_NULL
+                , STR_EMPTY
                 , STR_COLON_SELECTED
                 , STR_FOR
                 , STR_CHANGE
@@ -138,12 +121,12 @@ define([
                 , MakeOptionInput
                 , MakeOptionSelectBox  } = baseComponent;    
 
-    var InitListForBlockOption = function(thatBlock, optionPageSelector) {
-        var uuid = thatBlock.getUUID();
-        var blockContainerThis = thatBlock.getBlockContainerThis();
+    var InitListForBlockOption = function(thisBlock, optionPageSelector) {
+        var uuid = thisBlock.getUUID();
+        var blockContainerThis = thisBlock.getBlockContainerThis();
 
         /** --------------------------------- List for Option 이벤트 함수 바인딩 ---------------------------------- */    
-        var listforConditionListState = thatBlock.getState(STATE_listforConditionList);  
+        var listforConditionListState = thisBlock.getState(STATE_listforConditionList);  
         listforConditionListState.forEach((listforParam, index) => {
 
 
@@ -152,7 +135,7 @@ define([
              */
             $(document).off(STR_CLICK, vpCommon.wrapSelector(`#vpApiblockDeleteButton${index}${uuid}`));
             $(document).on(STR_CLICK, vpCommon.wrapSelector(`#vpApiblockDeleteButton${index}${uuid}`), function(event) {
-                var listforConditionListState = thatBlock.getState(STATE_listforConditionList);
+                var listforConditionListState = thisBlock.getState(STATE_listforConditionList);
             
                 if (listforConditionListState.length == 1) {
                      return;
@@ -160,10 +143,10 @@ define([
                             
                 listforConditionListState = DeleteOneArrayValueAndGet(listforConditionListState, index);
             
-                thatBlock.setState({
+                thisBlock.setState({
                     listforConditionList: listforConditionListState
                 });
-                var listforConditionCode = GenerateListforConditionList(thatBlock);
+                var listforConditionCode = GenerateListforConditionList(thisBlock);
                 $(VP_CLASS_PREFIX + VP_CLASS_APIBLOCK_BLOCK_HEADER + uuid).html(listforConditionCode);
             
                 blockContainerThis.renderBlockOptionTab();
@@ -177,8 +160,8 @@ define([
              */
             $(document).off(STR_CHANGE_KEYUP_PASTE, VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_LIST_FOR_ARG_1 + index + uuid);
             $(document).on(STR_CHANGE_KEYUP_PASTE, VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_LIST_FOR_ARG_1 + index + uuid, function(event) {
-                var listforConditionListState = thatBlock.getState(STATE_listforConditionList);
-                var listforConditionState = thatBlock.getState(STATE_listforConditionList)[index];
+                var listforConditionListState = thisBlock.getState(STATE_listforConditionList);
+                var listforConditionState = thisBlock.getState(STATE_listforConditionList)[index];
 
                 var updatedValue = {
                     ...listforConditionState
@@ -186,12 +169,12 @@ define([
                 }
      
                 listforConditionListState = UpdateOneArrayValueAndGet(listforConditionListState, index, updatedValue);
-                thatBlock.setState({
+                thisBlock.setState({
                     listforConditionList: listforConditionListState
                 });
          
 
-                var listforConditionCode = GenerateListforConditionList(thatBlock);
+                var listforConditionCode = GenerateListforConditionList(thisBlock);
                 $(VP_CLASS_PREFIX + VP_CLASS_APIBLOCK_BLOCK_HEADER + uuid).html(listforConditionCode);
 
                 event.stopPropagation();
@@ -203,8 +186,8 @@ define([
             $(document).off(STR_CHANGE_KEYUP_PASTE, VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_LIST_FOR_ARG_2 +index + uuid);
             $(document).on(STR_CHANGE_KEYUP_PASTE, VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_LIST_FOR_ARG_2 +index + uuid, function(event) {
                 // RenderInputRequiredColor(this);
-                var listforConditionListState = thatBlock.getState(STATE_listforConditionList);
-                var listforConditionState = thatBlock.getState(STATE_listforConditionList)[index];
+                var listforConditionListState = thisBlock.getState(STATE_listforConditionList);
+                var listforConditionState = thisBlock.getState(STATE_listforConditionList)[index];
 
                 var updatedValue = {
                     ...listforConditionState
@@ -212,10 +195,10 @@ define([
                 }
       
                 listforConditionListState = UpdateOneArrayValueAndGet(listforConditionListState, index, updatedValue);
-                thatBlock.setState({
+                thisBlock.setState({
                     [STATE_listforConditionList]: listforConditionListState
                 });
-                var listforConditionCode = GenerateListforConditionList(thatBlock);
+                var listforConditionCode = GenerateListforConditionList(thisBlock);
                 $(VP_CLASS_PREFIX + VP_CLASS_APIBLOCK_BLOCK_HEADER + uuid).html(listforConditionCode);
 
                 event.stopPropagation();
@@ -227,8 +210,8 @@ define([
             $(document).off(STR_CHANGE_KEYUP_PASTE, VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_LIST_FOR_ARG_3 + index + uuid);
             $(document).on(STR_CHANGE_KEYUP_PASTE, VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_LIST_FOR_ARG_3 + index + uuid, function(event) {
                 // RenderInputRequiredColor(this);
-                var listforConditionListState = thatBlock.getState(STATE_listforConditionList);
-                var listforConditionState = thatBlock.getState(STATE_listforConditionList)[index];
+                var listforConditionListState = thisBlock.getState(STATE_listforConditionList);
+                var listforConditionState = thisBlock.getState(STATE_listforConditionList)[index];
 
                 var updatedValue = {
                     ...listforConditionState
@@ -236,10 +219,10 @@ define([
                 }
       
                 listforConditionListState = UpdateOneArrayValueAndGet(listforConditionListState, index, updatedValue);
-                thatBlock.setState({
+                thisBlock.setState({
                     [STATE_listforConditionList]: listforConditionListState
                 });
-                var listforConditionCode = GenerateListforConditionList(thatBlock);
+                var listforConditionCode = GenerateListforConditionList(thisBlock);
                 $(VP_CLASS_PREFIX + VP_CLASS_APIBLOCK_BLOCK_HEADER + uuid).html(listforConditionCode);
 
                 event.stopPropagation();
@@ -248,8 +231,8 @@ define([
             $(document).off(STR_CHANGE, VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_LIST_FOR_ARG_3 + index  + uuid);
             $(document).on(STR_CHANGE, VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_LIST_FOR_ARG_3 + index  + uuid, function(event) {
                  // RenderInputRequiredColor(this);
-                var listforConditionListState = thatBlock.getState(STATE_listforConditionList);
-                var listforConditionState = thatBlock.getState(STATE_listforConditionList)[index];
+                var listforConditionListState = thisBlock.getState(STATE_listforConditionList);
+                var listforConditionState = thisBlock.getState(STATE_listforConditionList)[index];
  
                 var selectedValue = $(STR_COLON_SELECTED, this).val();
                 if (selectedValue == FOR_BLOCK_ARG3_TYPE.ZIP
@@ -262,10 +245,10 @@ define([
                         }
               
                         listforConditionListState = UpdateOneArrayValueAndGet(listforConditionListState, index, updatedValue);
-                        thatBlock.setState({
+                        thisBlock.setState({
                             [STATE_listforConditionList]: listforConditionListState
                         });
-                        var listforConditionCode = GenerateListforConditionList(thatBlock);
+                        var listforConditionCode = GenerateListforConditionList(thisBlock);
                         $(VP_CLASS_PREFIX + VP_CLASS_APIBLOCK_BLOCK_HEADER + uuid).html(listforConditionCode);
                         blockContainerThis.renderBlockOptionTab();
                 }
@@ -278,19 +261,19 @@ define([
              */
             $(document).off(STR_CHANGE_KEYUP_PASTE, VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_LIST_FOR_ARG_4 + index + uuid);
             $(document).on(STR_CHANGE_KEYUP_PASTE, VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_LIST_FOR_ARG_4 + index + uuid, function(event) {
-                var listforConditionListState = thatBlock.getState(STATE_listforConditionList);
-                var listforConditionState = thatBlock.getState(STATE_listforConditionList)[index];
+                var listforConditionListState = thisBlock.getState(STATE_listforConditionList);
+                var listforConditionState = thisBlock.getState(STATE_listforConditionList)[index];
 
                 var updatedValue = {
                     ...listforConditionState
                     , arg4 : $(this).val()
                 }
                 listforConditionListState = UpdateOneArrayValueAndGet(listforConditionListState, index, updatedValue);
-                thatBlock.setState({
+                thisBlock.setState({
                     listforConditionList: listforConditionListState
                 });
 
-                var listforConditionCode = GenerateListforConditionList(thatBlock);
+                var listforConditionCode = GenerateListforConditionList(thisBlock);
                 $(VP_CLASS_PREFIX + VP_CLASS_APIBLOCK_BLOCK_HEADER + uuid).html(listforConditionCode);
 
                 event.stopPropagation();
@@ -303,19 +286,19 @@ define([
              */
             $(document).off(STR_CHANGE_KEYUP_PASTE, VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_LIST_FOR_ARG_5 + index + uuid);
             $(document).on(STR_CHANGE_KEYUP_PASTE, VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_LIST_FOR_ARG_5 + index + uuid, function(event) {
-                var listforConditionListState = thatBlock.getState(STATE_listforConditionList);
-                var listforConditionState = thatBlock.getState(STATE_listforConditionList)[index];
+                var listforConditionListState = thisBlock.getState(STATE_listforConditionList);
+                var listforConditionState = thisBlock.getState(STATE_listforConditionList)[index];
 
                 var updatedValue = {
                     ...listforConditionState
                     , arg5 : $(this).val()
                 }
                 listforConditionListState = UpdateOneArrayValueAndGet(listforConditionListState, index, updatedValue);
-                thatBlock.setState({
+                thisBlock.setState({
                     listforConditionList: listforConditionListState
                 });
 
-                var listforConditionCode = GenerateListforConditionList(thatBlock);
+                var listforConditionCode = GenerateListforConditionList(thisBlock);
                 $(VP_CLASS_PREFIX + VP_CLASS_APIBLOCK_BLOCK_HEADER + uuid).html(listforConditionCode);
 
                 event.stopPropagation();
@@ -329,19 +312,19 @@ define([
             // $(document).off(STR_CHANGE_KEYUP_PASTE, `.vp_apiblockBlockoptionListforArg6${index}${uuid}`);
             $(document).off(STR_CHANGE_KEYUP_PASTE, VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_LIST_FOR_ARG_6 + index + uuid);
             $(document).on(STR_CHANGE_KEYUP_PASTE, VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_LIST_FOR_ARG_6 + index + uuid, function(event) {
-                var listforConditionListState = thatBlock.getState(STATE_listforConditionList);
-                var listforConditionState = thatBlock.getState(STATE_listforConditionList)[index];
+                var listforConditionListState = thisBlock.getState(STATE_listforConditionList);
+                var listforConditionState = thisBlock.getState(STATE_listforConditionList)[index];
 
                 var updatedValue = {
                     ...listforConditionState
                     , arg6 : $(this).val()
                 }
                 listforConditionListState = UpdateOneArrayValueAndGet(listforConditionListState, index, updatedValue);
-                thatBlock.setState({
+                thisBlock.setState({
                     listforConditionList: listforConditionListState
                 });
 
-                var listforConditionCode = GenerateListforConditionList(thatBlock);
+                var listforConditionCode = GenerateListforConditionList(thisBlock);
                 $(VP_CLASS_PREFIX + VP_CLASS_APIBLOCK_BLOCK_HEADER + uuid).html(listforConditionCode);
 
                 event.stopPropagation();
@@ -355,19 +338,19 @@ define([
             // $(document).off(STR_CHANGE_KEYUP_PASTE, `.vp_apiblockBlockoptionListforArg7${index}${uuid}`);
             $(document).off(STR_CHANGE_KEYUP_PASTE, VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_LIST_FOR_ARG_7 + index + uuid);
             $(document).on(STR_CHANGE_KEYUP_PASTE, VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_LIST_FOR_ARG_7 + index + uuid, function(event) {
-                var listforConditionListState = thatBlock.getState(STATE_listforConditionList);
-                var listforConditionState = thatBlock.getState(STATE_listforConditionList)[index];
+                var listforConditionListState = thisBlock.getState(STATE_listforConditionList);
+                var listforConditionState = thisBlock.getState(STATE_listforConditionList)[index];
 
                 var updatedValue = {
                     ...listforConditionState
                     , arg7 : $(this).val()
                 }
                 listforConditionListState = UpdateOneArrayValueAndGet(listforConditionListState, index, updatedValue);
-                thatBlock.setState({
+                thisBlock.setState({
                     listforConditionList: listforConditionListState
                 });
 
-                var listforConditionCode = GenerateListforConditionList(thatBlock);
+                var listforConditionCode = GenerateListforConditionList(thisBlock);
                 $(VP_CLASS_PREFIX + VP_CLASS_APIBLOCK_BLOCK_HEADER + uuid).html(listforConditionCode);
 
                 event.stopPropagation();
@@ -380,8 +363,8 @@ define([
              */
             $(document).off(STR_CHANGE_KEYUP_PASTE, VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_LIST_FOR_ARG_10 + index + uuid);
             $(document).on(STR_CHANGE_KEYUP_PASTE, VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_LIST_FOR_ARG_10 + index + uuid, function(event) {
-                var listforConditionListState = thatBlock.getState(STATE_listforConditionList);
-                var listforConditionState = thatBlock.getState(STATE_listforConditionList)[index];
+                var listforConditionListState = thisBlock.getState(STATE_listforConditionList);
+                var listforConditionState = thisBlock.getState(STATE_listforConditionList)[index];
 
                 var updatedValue = {
                     ...listforConditionState
@@ -389,10 +372,10 @@ define([
                 }
 
                 listforConditionListState = UpdateOneArrayValueAndGet(listforConditionListState, index, updatedValue);
-                thatBlock.setState({
+                thisBlock.setState({
                     listforConditionList: listforConditionListState
                 });
-                var listforConditionCode = GenerateListforConditionList(thatBlock);
+                var listforConditionCode = GenerateListforConditionList(thisBlock);
                 $(VP_CLASS_PREFIX + VP_CLASS_APIBLOCK_BLOCK_HEADER + uuid).html(listforConditionCode);
                 blockContainerThis.renderBlockOptionTab();
                 event.stopPropagation();
@@ -401,19 +384,19 @@ define([
             /** List for arg11 변경 */
             $(document).off(STR_CHANGE_KEYUP_PASTE, VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_LIST_FOR_ARG_11 + index + uuid);
             $(document).on(STR_CHANGE_KEYUP_PASTE, VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_LIST_FOR_ARG_11 + index + uuid, function(event) {
-                var listforConditionListState = thatBlock.getState(STATE_listforConditionList);
-                var listforConditionState = thatBlock.getState(STATE_listforConditionList)[index];
+                var listforConditionListState = thisBlock.getState(STATE_listforConditionList);
+                var listforConditionState = thisBlock.getState(STATE_listforConditionList)[index];
             
                 var updatedValue = {
                     ...listforConditionState
                     , arg11 : $(this).val()
                 }
                 listforConditionListState = UpdateOneArrayValueAndGet(listforConditionListState, index, updatedValue);
-                thatBlock.setState({
+                thisBlock.setState({
                     listforConditionList: listforConditionListState
                 });
             
-                var listforConditionCode = GenerateListforConditionList(thatBlock);
+                var listforConditionCode = GenerateListforConditionList(thisBlock);
                 $(VP_CLASS_PREFIX + VP_CLASS_APIBLOCK_BLOCK_HEADER + uuid).html(listforConditionCode);
             
                 event.stopPropagation();
@@ -426,8 +409,8 @@ define([
              */
             $(document).off(STR_CHANGE_KEYUP_PASTE, VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_LIST_FOR_ARG_12 + index + uuid);
             $(document).on(STR_CHANGE_KEYUP_PASTE, VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_LIST_FOR_ARG_12 + index + uuid, function(event) {
-                var listforConditionListState = thatBlock.getState(STATE_listforConditionList);
-                var listforConditionState = thatBlock.getState(STATE_listforConditionList)[index];
+                var listforConditionListState = thisBlock.getState(STATE_listforConditionList);
+                var listforConditionState = thisBlock.getState(STATE_listforConditionList)[index];
 
                 var updatedValue = {
                     ...listforConditionState
@@ -435,10 +418,10 @@ define([
                 }
 
                 listforConditionListState = UpdateOneArrayValueAndGet(listforConditionListState, index, updatedValue);
-                thatBlock.setState({
+                thisBlock.setState({
                     listforConditionList: listforConditionListState
                 });
-                var listforConditionCode = GenerateListforConditionList(thatBlock);
+                var listforConditionCode = GenerateListforConditionList(thisBlock);
                 $(VP_CLASS_PREFIX + VP_CLASS_APIBLOCK_BLOCK_HEADER + uuid).html(listforConditionCode);
 
                 event.stopPropagation();
@@ -451,19 +434,19 @@ define([
              */
             $(document).off(STR_CHANGE_KEYUP_PASTE, VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_LIST_FOR_ARG_13 + index + uuid);
             $(document).on(STR_CHANGE_KEYUP_PASTE, VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_LIST_FOR_ARG_13 + index + uuid, function(event) {
-                var listforConditionListState = thatBlock.getState(STATE_listforConditionList);
-                var listforConditionState = thatBlock.getState(STATE_listforConditionList)[index];
+                var listforConditionListState = thisBlock.getState(STATE_listforConditionList);
+                var listforConditionState = thisBlock.getState(STATE_listforConditionList)[index];
             
                 var updatedValue = {
                     ...listforConditionState
                     , arg13 : $(this).val()
                 }
                 listforConditionListState = UpdateOneArrayValueAndGet(listforConditionListState, index, updatedValue);
-                thatBlock.setState({
+                thisBlock.setState({
                     listforConditionList: listforConditionListState
                 });
             
-                var listforConditionCode = GenerateListforConditionList(thatBlock);
+                var listforConditionCode = GenerateListforConditionList(thisBlock);
                 $(VP_CLASS_PREFIX + VP_CLASS_APIBLOCK_BLOCK_HEADER + uuid).html(listforConditionCode);
             
                 event.stopPropagation();
@@ -478,8 +461,8 @@ define([
             // $(document).off(STR_CHANGE, `.vp_apiblockBlockoptionListforArg14${index}${uuid}`);
             $(document).off(STR_CHANGE_KEYUP_PASTE, VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_LIST_FOR_ARG_14 + index + uuid);
             $(document).on(STR_CHANGE_KEYUP_PASTE, VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_LIST_FOR_ARG_14 + index + uuid, function(event) {
-                var listforConditionListState = thatBlock.getState(STATE_listforConditionList);
-                var listforConditionState = thatBlock.getState(STATE_listforConditionList)[index];
+                var listforConditionListState = thisBlock.getState(STATE_listforConditionList);
+                var listforConditionState = thisBlock.getState(STATE_listforConditionList)[index];
 
                 var updatedValue = {
                     ...listforConditionState
@@ -487,10 +470,10 @@ define([
                 }
 
                 listforConditionListState = UpdateOneArrayValueAndGet(listforConditionListState, index, updatedValue);
-                thatBlock.setState({
+                thisBlock.setState({
                     listforConditionList: listforConditionListState
                 });
-                var listforConditionCode = GenerateListforConditionList(thatBlock);
+                var listforConditionCode = GenerateListforConditionList(thisBlock);
                 $(VP_CLASS_PREFIX + VP_CLASS_APIBLOCK_BLOCK_HEADER + uuid).html(listforConditionCode);
 
                 event.stopPropagation();
@@ -503,19 +486,19 @@ define([
              */
             $(document).off(STR_CHANGE_KEYUP_PASTE, VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_LIST_FOR_ARG_15 + index + uuid);
             $(document).on(STR_CHANGE_KEYUP_PASTE, VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_LIST_FOR_ARG_15 + index + uuid, function(event) {
-                var listforConditionListState = thatBlock.getState(STATE_listforConditionList);
-                var listforConditionState = thatBlock.getState(STATE_listforConditionList)[index];
+                var listforConditionListState = thisBlock.getState(STATE_listforConditionList);
+                var listforConditionState = thisBlock.getState(STATE_listforConditionList)[index];
             
                 var updatedValue = {
                     ...listforConditionState
                     , arg15 : $(this).val()
                 }
                 listforConditionListState = UpdateOneArrayValueAndGet(listforConditionListState, index, updatedValue);
-                thatBlock.setState({
+                thisBlock.setState({
                     listforConditionList: listforConditionListState
                 });
             
-                var listforConditionCode = GenerateListforConditionList(thatBlock);
+                var listforConditionCode = GenerateListforConditionList(thisBlock);
                 $(VP_CLASS_PREFIX + VP_CLASS_APIBLOCK_BLOCK_HEADER + uuid).html(listforConditionCode);
             
                 event.stopPropagation();
@@ -529,10 +512,10 @@ define([
          */
         $(document).off(STR_CLICK, vpCommon.wrapSelector(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_LIST_FOR_PLUS + uuid));
         $(document).on(STR_CLICK, vpCommon.wrapSelector(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_LIST_FOR_PLUS + uuid), function() {
-            var listforConditionListState = thatBlock.getState(STATE_listforConditionList);
+            var listforConditionListState = thisBlock.getState(STATE_listforConditionList);
             var listforConditionLength = listforConditionListState.length;
 
-            thatBlock.addVariableIndex();
+            thisBlock.addVariableIndex();
             
             var newCondition = {
                 arg1:  ''
@@ -556,11 +539,11 @@ define([
                 , arg10InputStr: ''
             }
             listforConditionListState = CreateOneArrayValueAndGet(listforConditionListState, listforConditionLength, newCondition);
-            thatBlock.setState({
+            thisBlock.setState({
                 listforConditionList: listforConditionListState
             });
 
-            var listforfConditionCode = GenerateListforConditionList(thatBlock);
+            var listforfConditionCode = GenerateListforConditionList(thisBlock);
             $(VP_CLASS_PREFIX + VP_CLASS_APIBLOCK_BLOCK_HEADER + uuid).html(listforfConditionCode);
 
             blockContainerThis.renderBlockOptionTab();
@@ -572,11 +555,11 @@ define([
          */
         $(document).off(STR_CHANGE_KEYUP_PASTE, VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_LIST_FOR_RETURN_VAR + uuid);
         $(document).on(STR_CHANGE_KEYUP_PASTE, VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_LIST_FOR_RETURN_VAR + uuid, function(event) {
-            thatBlock.setState({
+            thisBlock.setState({
                 listforReturnVar: $(this).val()
             });
 
-            var listforfConditionCode = GenerateListforConditionList(thatBlock);
+            var listforfConditionCode = GenerateListforConditionList(thisBlock);
             $(VP_CLASS_PREFIX + VP_CLASS_APIBLOCK_BLOCK_HEADER + uuid).html(listforfConditionCode);
 
             event.stopPropagation();
@@ -588,11 +571,11 @@ define([
          */
         $(document).off(STR_CHANGE_KEYUP_PASTE, VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_LIST_FOR_PREV_EXPRESSION + uuid);
         $(document).on(STR_CHANGE_KEYUP_PASTE, VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_LIST_FOR_PREV_EXPRESSION + uuid, function(event) {
-            thatBlock.setState({
+            thisBlock.setState({
                 listforPrevExpression: $(this).val()
             });
 
-            var listforfConditionCode = GenerateListforConditionList(thatBlock);
+            var listforfConditionCode = GenerateListforConditionList(thisBlock);
             $(VP_CLASS_PREFIX + VP_CLASS_APIBLOCK_BLOCK_HEADER + uuid).html(listforfConditionCode);
 
             event.stopPropagation();
@@ -606,18 +589,18 @@ define([
         $(document).on(STR_CHANGE, VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_FOR_TYPE_SELECT +uuid, function(event) {
             var selectedVal = $(STR_COLON_SELECTED, this).val();
 
-            thatBlock.setState({
+            thisBlock.setState({
                 forBlockOptionType: $(STR_COLON_SELECTED, this).val()
             });
 
             if ( selectedVal == FOR_BLOCK_TYPE.FOR ) {
-                var forParamStr = GenerateForParam(thatBlock);
+                var forParamStr = GenerateForParam(thisBlock);
                 $(VP_CLASS_PREFIX + VP_CLASS_APIBLOCK_BLOCK_HEADER + uuid).html(forParamStr);
-                thatBlock.getBlockHeaderDom().find(STR_STRONG).css(STR_DISPLAY, STR_FLEX);
+                thisBlock.getBlockHeaderDom().find(STR_STRONG).css(STR_DISPLAY, STR_FLEX);
             } else {
-                var listForStr = GenerateListforConditionList(thatBlock);
+                var listForStr = GenerateListforConditionList(thisBlock);
                 $(VP_CLASS_PREFIX + VP_CLASS_APIBLOCK_BLOCK_HEADER + uuid).html(listForStr);
-                thatBlock.getBlockHeaderDom().find(STR_STRONG).css(STR_DISPLAY, STR_NONE);
+                thisBlock.getBlockHeaderDom().find(STR_STRONG).css(STR_DISPLAY, STR_NONE);
             }
 
             blockContainerThis.renderBlockOptionTab();
@@ -627,8 +610,8 @@ define([
 
 
         var bindSelectValueEventFunc_for = function(selectedValue, index, argType) {
-            var listforConditionListState = thatBlock.getState(STATE_listforConditionList);
-            var listforConditionState = thatBlock.getState(STATE_listforConditionList)[index];
+            var listforConditionListState = thisBlock.getState(STATE_listforConditionList);
+            var listforConditionState = thisBlock.getState(STATE_listforConditionList)[index];
             var updatedValue;
         
             if (FOR_BLOCK_SELECT_VALUE_ARG_TYPE.ARG1 == argType) {
@@ -691,7 +674,7 @@ define([
                     ...listforConditionState
                     , arg14 : selectedValue
                 }
-                if (selectedValue == 'none' || selectedValue == STR_NULL) {
+                if (selectedValue == 'none' || selectedValue == STR_EMPTY) {
                     $(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_LIST_FOR_ARG_14 + index + uuid).addClass(VP_CLASS_STYLE_BGCOLOR_C4C4C4);
                     $(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_LIST_FOR_ARG_15 + index + uuid).attr("disabled", true);
                     $(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_LIST_FOR_ARG_15 + index + uuid).addClass(VP_CLASS_STYLE_BGCOLOR_C4C4C4);
@@ -718,27 +701,27 @@ define([
                 }
             }
             else if (FOR_BLOCK_SELECT_VALUE_ARG_TYPE.RETURN_VAR == argType) {
-                thatBlock.setState({
+                thisBlock.setState({
                     listforReturnVar: selectedValue
                 });
-                var listforConditionCode = GenerateListforConditionList(thatBlock);
+                var listforConditionCode = GenerateListforConditionList(thisBlock);
                 $(VP_CLASS_PREFIX + VP_CLASS_APIBLOCK_BLOCK_HEADER + uuid).html(listforConditionCode);
                 return;
             } else if (FOR_BLOCK_SELECT_VALUE_ARG_TYPE.PREV_EXPRESSION == argType) {
-                thatBlock.setState({
+                thisBlock.setState({
                     listforPrevExpression: selectedValue
                 });
-                var listforConditionCode = GenerateListforConditionList(thatBlock);
+                var listforConditionCode = GenerateListforConditionList(thisBlock);
                 $(VP_CLASS_PREFIX + VP_CLASS_APIBLOCK_BLOCK_HEADER + uuid).html(listforConditionCode);
                 return;
             }
         
             listforConditionListState = UpdateOneArrayValueAndGet(listforConditionListState, index, updatedValue);
-            thatBlock.setState({
+            thisBlock.setState({
                 [STATE_listforConditionList]: listforConditionListState
             });
         
-            var listforConditionCode = GenerateListforConditionList(thatBlock);
+            var listforConditionCode = GenerateListforConditionList(thisBlock);
             $(VP_CLASS_PREFIX + VP_CLASS_APIBLOCK_BLOCK_HEADER + uuid).html(listforConditionCode);
 
             if (FOR_BLOCK_SELECT_VALUE_ARG_TYPE.ARG3 == argType) {
@@ -754,21 +737,21 @@ define([
         /** List For option 렌더링 */
         var renderThisComponent = function() {
 
-            var forBlockOption = MakeOptionContainer();
+            var forBlockOption = MakeOptionContainer(thisBlock);
 
-            var forBlockOptionType = thatBlock.getState(STATE_forBlockOptionType);
-            var listforReturnVarState = thatBlock.getState(STATE_listforReturnVar);
-            var listforPrevExpression = thatBlock.getState(STATE_listforPrevExpression);
+            var forBlockOptionType = thisBlock.getState(STATE_forBlockOptionType);
+            var listforReturnVarState = thisBlock.getState(STATE_listforReturnVar);
+            var listforPrevExpression = thisBlock.getState(STATE_listforPrevExpression);
 
             /* ------------- For html dom 생성 ------------------ */
             var forName = 'List For';
 
             var selectedFor = forBlockOptionType == FOR_BLOCK_TYPE.FOR 
                                     ? STR_SELECTED 
-                                    : STR_NULL;
+                                    : STR_EMPTY;
             var selectedListfor = forBlockOptionType == FOR_BLOCK_TYPE.LIST_FOR
                                     ? STR_SELECTED 
-                                    : STR_NULL;
+                                    : STR_EMPTY;
     
             var sbforNameDom = new sb.StringBuilder();
             sbforNameDom.appendFormatLine("<div class='{0}'>", 'vp-apiblock-style-margin-top-5px');
@@ -853,7 +836,7 @@ define([
             forBlockOption.append(sbListforReturnVar.toString());
 
             var listforParamDomBody = $('<div></div>');
-            var listforConditionListState = thatBlock.getState(STATE_listforConditionList);  
+            var listforConditionListState = thisBlock.getState(STATE_listforConditionList);  
             listforConditionListState.forEach((listforParam, index) => {
                 var listforParamDomContainer = $(`<div class='vp-apiblock-blockoption-block 
                                                               vp-apiblock-style-flex-column-center'>
@@ -1001,7 +984,7 @@ define([
                 
                     sbListForCondition2ArgContainer.appendLine(sbforParamArg5);
                 }            
-                // arg3 == STR_NULL
+                // arg3 == STR_EMPTY
                 // || 
                 if (arg3 == FOR_BLOCK_ARG3_TYPE.ZIP 
                     || arg3 == FOR_BLOCK_ARG3_TYPE.RANGE 
@@ -1159,14 +1142,14 @@ define([
             $(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_LIST_FOR_RETURN_VAR + uuid).val(listforReturnVarState);
             $(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_LIST_FOR_PREV_EXPRESSION + uuid).val(listforPrevExpression);
 
-            var listforConditionListState = thatBlock.getState(STATE_listforConditionList);  
+            var listforConditionListState = thisBlock.getState(STATE_listforConditionList);  
             listforConditionListState.forEach((listforParam, index) => {
                 const { arg1, arg2, arg3, arg4, arg5, arg6, arg7,
                         arg10, arg11, arg12, arg13, arg14, arg15 } = listforParam;
                 $(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_LIST_FOR_ARG_1 + index + uuid).val(arg1);
                 $(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_LIST_FOR_ARG_2 + index + uuid).val(arg2);
                 if (arg3 == FOR_BLOCK_ARG3_TYPE.INPUT_STR) {
-                    $(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_LIST_FOR_ARG_3 + index + uuid).val(STR_NULL);
+                    $(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_LIST_FOR_ARG_3 + index + uuid).val(STR_EMPTY);
                 } else {
                     $(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_LIST_FOR_ARG_3 + index + uuid).val(arg3);
                 }
@@ -1191,7 +1174,7 @@ define([
                 $(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_LIST_FOR_ARG_14 + index + uuid).val(arg14);
                 $(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_LIST_FOR_ARG_15 + index + uuid).val(arg15);
 
-                if (arg14 == 'none' || arg14 == STR_NULL) {
+                if (arg14 == 'none' || arg14 == STR_EMPTY) {
                     $(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_LIST_FOR_ARG_14 + index + uuid).addClass(VP_CLASS_STYLE_BGCOLOR_C4C4C4);
                     $(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_LIST_FOR_ARG_15 + index + uuid).attr("disabled", true);
                     $(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_LIST_FOR_ARG_15 + index + uuid).addClass(VP_CLASS_STYLE_BGCOLOR_C4C4C4);
@@ -1203,9 +1186,10 @@ define([
                 }   
             });
 
+            return forBlockOption;
         }
 
-        renderThisComponent();
+        return renderThisComponent();
     }
 
     return InitListForBlockOption;
