@@ -5,29 +5,29 @@ define([
     , 'nbextensions/visualpython/src/common/StringBuilder'
 
     , '../../api.js'    
-    , '../../config.js'
+
     , '../../constData.js'
-    , '../../blockRenderer.js'
+    
     , '../base/index.js'
 ], function ( $, vpCommon, vpConst, sb, 
             //   block
               api
-              , config
               , constData
-              , blockRenderer
               , baseComponent ) {
 
 
     const { MakeOptionContainer } = baseComponent;
-    var InitTryBlockOption = function(thatBlock, optionPageSelector) {
+    var InitTryBlockOption = function(thisBlock, optionPageSelector) {
         var renderThisComponent = function() {
-            var tryBlockOption = MakeOptionContainer();
+            var tryBlockOption = MakeOptionContainer(thisBlock);
             tryBlockOption.append('<div>(N/A)</div>');
 
             /**block option 탭에 렌더링된 dom객체 생성 */
             $(optionPageSelector).append(tryBlockOption);
+
+            return tryBlockOption;
         }
-        renderThisComponent();
+        return renderThisComponent();
     }
 
     return InitTryBlockOption;
