@@ -7,29 +7,14 @@ define([
     , 'nbextensions/visualpython/src/common/vpFuncJS'
 
     , './api.js'
-    , './config.js'
+
     , './constData.js'
     , './init.js'
 
 ], function (requirejs, $, vpCommon, vpConst, sb, vpFuncJS,
-            api, config, constData, init) {
-    const { GetImageUrl } = api;
-    const { PROCESS_MODE } = config;
-    const { VP_CLASS_PREFIX
-        
-            , VP_CLASS_APIBLOCK_MAIN
-            , VP_CLASS_APIBLOCK_BOARD
-            , VP_CLASS_APIBLOCK_BUTTONS
-            , VP_CLASS_APIBLOCK_OPTION_TAB
-            , VP_CLASS_APIBLOCK_MENU_BTN
-            , VP_CLASS_APIBLOCK_CODELINE_ELLIPSIS
+            api,  constData, init) {
 
-            , STR_PARENT
-
-            , STR_WIDTH
-            , STR_MAX_WIDTH
-        
-            , API_BLOCK_HTML_URL_PATH
+    const { API_BLOCK_HTML_URL_PATH
             , API_BLOCK_INDEX_CSS } = constData;
 
     // 옵션 속성
@@ -103,29 +88,25 @@ define([
      * html 내부 binding 처리
      */
     ImportPackage.prototype.initHtml = function() {
-        // var that = this;
+        var that = this;
         this.loadCss(Jupyter.notebook.base_url + vpConst.BASE_PATH + vpConst.STYLE_PATH + API_BLOCK_INDEX_CSS);
         this.blockContainer = init();
         this.blockContainer.setImportPackageThis(this);
         this.blockContainer.setAPIBlockMetadataHandler();
 
         if (this.metadata) {
-            // console.log('metadata 있음');
+            // metadata 있음;
             this.blockContainer.loadAPIBlockMetadata(this.metadata);
         } else {
-            // console.log('metadata 없음 -> 새로 만듬', this.metadata);
+            // metadata 없음 -> 새로 만듬;
             this.blockContainer.setAPIBlockMetadata();
         }
   
-
         /** API Block 화면 좌우로 resize 할 경우 option page width 계산 */
         $( window ).resize( function() {
-            var optionPageRect = $(vpCommon.wrapSelector(VP_CLASS_PREFIX + VP_CLASS_APIBLOCK_OPTION_TAB))[0].getBoundingClientRect();
-            var optionPageRectWidth = optionPageRect.width; 
-     
-            $(vpCommon.wrapSelector(VP_CLASS_PREFIX + VP_CLASS_APIBLOCK_OPTION_TAB)).css('right', 0);
-            $(vpCommon.wrapSelector(VP_CLASS_PREFIX + VP_CLASS_APIBLOCK_OPTION_TAB)).css('left', 'initial');
-            $(vpCommon.wrapSelector(VP_CLASS_PREFIX + VP_CLASS_APIBLOCK_MENU_BTN)).css('right', optionPageRectWidth + 5);
+            if (that.blockContainer.getIsOptionPageResize() == false) {
+                that.blockContainer.resizeAPIblock();
+            }
         });
     }
 
@@ -146,15 +127,19 @@ define([
         return this.uuid;
     }
 
+    ImportPackage.prototype.getBlockContainer = function() {
+        return this.blockContainer;
+    }
+
     /**
      * 코드 생성
      * @param {boolean} addCell 
      * @param {boolean} exec 실행여부
+     * @param {boolean} isClicked true면 node 단위의 코드 실행, false면 전체 단위의 코드 실행
      */
     ImportPackage.prototype.generateCode = function( addCell, exec, isClicked ) {
     
         // validate code 
-     
         if (!this.optionValidation()) return;
 
         // make code
@@ -162,11 +147,12 @@ define([
         if (isClicked) {
             result = this.blockContainer.getAPIBlockCode();
         } else {
-            result = this.blockContainer.makeCode();
+            result = this.blockContainer.makeAllCode();
         }
-        
-        if (this.blockContainer.getBlockList().length == 0 || !result) {
-            result = '# Auto-Generated by VisualPython - API Block';
+    
+        if (this.blockContainer.getBlockList().length == 0 
+            || !result) {
+            result = '';
         }
 
         /** add code */
@@ -175,13 +161,8 @@ define([
             this.blockContainer.saveAPIBlockMetadata();
             return result;
         }
-        // console.log('this.blockContainer.getBlockList()',this.blockContainer.getBlockList());
-        // console.log('result',result);
         // execute code
         this.cellExecute(result, exec);
-
-        // code run시 메타데이터 생성
-        this.blockContainer.saveAPIBlockMetadata();
     }
 
     return {
