@@ -5,6 +5,8 @@ define([
     , 'nbextensions/visualpython/src/common/StringBuilder'
 ], function (requirejs, $, vpConst, sb) {
 
+    let isAPIListRunCode = true;
+
     /**
      * 옵션 페이지 로드.
      * @param {String} destSelector 로드될 목적지 선택자
@@ -92,6 +94,7 @@ define([
                 sbSelector.appendFormat(" {0}", arguments[idx]);
             }
         }
+        // console.log('wrapSelector', sbSelector.toString());
         return sbSelector.toString();
     }
 
@@ -167,25 +170,27 @@ define([
      * @param {string} titleStr 
      */
     var renderAlertModal = function(titleStr) {
-        // load css
-        loadCss( Jupyter.notebook.base_url + vpConst.BASE_PATH + vpConst.STYLE_PATH + "component/alertModal.css");
-        // set html url
-        var loadURL = Jupyter.notebook.base_url + vpConst.BASE_PATH + vpConst.SOURCE_PATH + "component/alertModal.html";
-        // load alertModal html
-        $(`<div id="vp_alertModal"></div>`)
-            .load(loadURL, function() {
-                // bind 이벤트 함수
+        if (isAPIListRunCode == true) {
+            // load css
+            loadCss( Jupyter.notebook.base_url + vpConst.BASE_PATH + vpConst.STYLE_PATH + "component/alertModal.css");
+            // set html url
+            var loadURL = Jupyter.notebook.base_url + vpConst.BASE_PATH + vpConst.SOURCE_PATH + "component/alertModal.html";
+            // load alertModal html
+            $(`<div id="vp_alertModal"></div>`)
+                .load(loadURL, function() {
+                    // bind 이벤트 함수
 
-                // alertModal창 메세지 출력
-                $('.vp-alertModal-titleStr').html(titleStr);
-                // alertModal창 확인 버튼 누를시
-                $('.vp-alertModal-yes').click( function() {
-                    $('body').find('#vp_alertModal').remove();
-                    // 종료후 head 태그에 import된 alertModal.css와 alertModal.html을 삭제함
-                    removeHeadScript("alertModal");
-                });   
-        })
-        .appendTo("body");
+                    // alertModal창 메세지 출력
+                    $('.vp-alertModal-titleStr').html(titleStr);
+                    // alertModal창 확인 버튼 누를시
+                    $('.vp-alertModal-yes').click( function() {
+                        $('body').find('#vp_alertModal').remove();
+                        // 종료후 head 태그에 import된 alertModal.css와 alertModal.html을 삭제함
+                        removeHeadScript("alertModal");
+                    });   
+            })
+            .appendTo("body");
+        }
     }
 
     /** 
@@ -201,13 +206,13 @@ define([
         $(`<div id="vp_loadingBar"></div>`)
             .load(loadURL, function() {
         })
-        .appendTo(".directoryComponent-container");
+        .appendTo(".fileNavigationPage-directory-container");
     }
 
     /**
      * 성공 메세지를 화면 우측 오른쪽에 띄우는 함수
      * 메세지는 3초후 사라진다.
-     * @param {string}} titleStr 
+     * @param {string} titleStr 
      */
     var renderSuccessMessage = function(titleStr) {
         loadCss( Jupyter.notebook.base_url + vpConst.BASE_PATH + vpConst.STYLE_PATH + "component/successMessage.css");
@@ -235,6 +240,15 @@ define([
             .load(loadURL, callback)
         .appendTo(".FileNavigationPage-inner");
     }
+
+    var setIsAPIListRunCode = function(isAPIListRunCode_param) {
+        isAPIListRunCode = isAPIListRunCode_param;
+    }
+
+    var getIsAPIListRunCode = function() {
+        return isAPIListRunCode;
+    }
+
     return {
         loadHtml: loadHtml
         , getUUID: getUUID
@@ -250,5 +264,7 @@ define([
         , renderSuccessMessage: renderSuccessMessage
         , renderYesOrNoModal: renderYesOrNoModal
         , removeHeadScript: removeHeadScript
+        , setIsAPIListRunCode: setIsAPIListRunCode
+        , getIsAPIListRunCode: getIsAPIListRunCode
     };
 });
\ No newline at end of file
