@@ -76,7 +76,8 @@ define([
      * @param {function} callback 호출자(컨테이너) 의 콜백함수
      */
     var initOption = function(callback, meta) {
-        vpCommon.loadHtml(vpCommon.wrapSelector(vpCommon.formatString("#{0}", vpConst.OPTION_GREEN_ROOM)), "matplotlib/plot.html", optionLoadCallback, callback, meta);
+        // vpCommon.loadHtml(vpCommon.wrapSelector(vpCommon.formatString("#{0}", vpConst.OPTION_GREEN_ROOM)), "matplotlib/plot.html", optionLoadCallback, callback, meta);
+        vpCommon.loadHtml(vpCommon.wrapSelector(vpCommon.formatString("#{0}", vpConst.OPTION_GREEN_ROOM)), "pandas/common/commonEmptyPage.html", optionLoadCallback, callback, meta);
     }
 
     /**
@@ -118,6 +119,220 @@ define([
         this.loadCss(Jupyter.notebook.base_url + vpConst.BASE_PATH + vpConst.STYLE_PATH + "matplotlib/plot.css");
 
         this.showFunctionTitle();
+
+        // init html
+        var sbPageContent = new sb.StringBuilder();
+        var sbTagString = new sb.StringBuilder();
+
+        // prefix code 입력 영역
+        sbPageContent.appendLine(this.createPrefixCode());
+
+        // Popup Box. variable view box
+        sbTagString.clear();
+        sbTagString.appendLine('<div id="vp_varViewBox" class="vp-var-view-box">');
+        sbTagString.appendLine('<div class="vp-icon-btn vp-close-view"></div>');
+        // variable list
+        sbTagString.appendLine('<div class="vp-var-view-div">');
+        sbTagString.appendLine('<table id="vp_varViewList" class="vp-option-table vp-var-view-list no-selection">');
+        sbTagString.appendLine('<colgroup><col width="40%"/><col width="*"/></colgroup>');
+        sbTagString.appendLine('<thead>');
+        sbTagString.appendLine('<tr><th>Variable</th><th>DataType</th></tr>');
+        sbTagString.appendLine('<tr><th colspan="2"><hr style="margin: 0px;"/></th></tr>');
+        sbTagString.appendLine('</thead>');
+        sbTagString.appendLine('<tbody>');
+        sbTagString.appendLine('</tbody>');
+        sbTagString.appendLine('</table>');
+        sbTagString.appendLine('</div>');
+        sbTagString.appendLine('<hr style="margin: 0px;"/>');
+        // detail
+        sbTagString.appendLine('<div id="vp_varViewDetail">');
+        sbTagString.appendLine('<table class="vp-option-table vp-var-view-detail no-selection">');
+        sbTagString.appendLine('<colgroup><col width="40%"/><col width="*"/></colgroup>');
+        sbTagString.appendLine('<thead><tr><th>columns</th><th>methods</th></tr></thead>');
+        sbTagString.appendLine('<tbody>');
+        sbTagString.appendLine('<tr><td><div id="vp_varDetailColList" class="vp-column-select"></div></td>');
+        sbTagString.appendLine('<td><div id="vp_varDetailArray" class="vp-method-select"></div></td></tr>');
+        sbTagString.appendLine('</tbody>');
+        sbTagString.appendLine('</table>');
+        sbTagString.appendLine('</div>');
+        // footer
+        sbTagString.appendLine('<div class="var-view-footer">');
+        sbTagString.appendLine('<input id="vp_varSelectCode" type="text" class="vp-input" readonly/>');
+        sbTagString.appendLine('<input id="vp_varSelectBtn" type="button" value="select"/>');
+        sbTagString.appendLine('</div>');
+        sbTagString.appendLine('</div>');
+        sbPageContent.appendLine(sbTagString.toString());
+
+        // Box 1. Required Input & Output
+        var accBoxRequire = this.createOptionContainer(vpConst.API_REQUIRE_OPTION_BOX_CAPTION);
+        accBoxRequire.setOpenBox(true);
+
+        sbTagString.clear();
+        // 대상변수 자동입력 칸 //FIXME:
+        sbTagString.appendLine('<input type="hidden" class="vp-input input-single" id="i0" value="plt"/>');
+
+        sbTagString.appendFormatLine('<div class="{0} {1}">{2}</div>', 'vp-thead', vpConst.COLOR_FONT_ORANGE, 'Chart Type');
+        sbTagString.appendFormatLine('<select id="{0}" class="{1}"></select>', 'kind', 'vp-select option-select');
+        accBoxRequire.appendContent(sbTagString.toString());
+
+        sbTagString.clear();
+        sbTagString.appendFormatLine('<div id="{0}" class="vp-plot-kind">', 'vp_plotKind');
+        this.plotKind.forEach(kind => {
+            sbTagString.appendFormatLine('<div class="vp-plot-item" data-kind="{0}" data-show-text="{1}">'
+                                        , kind, this.plotKindLang[kind]);
+            sbTagString.appendFormatLine('<div class="vp-plot-thumb {0}"></div>', kind);
+            sbTagString.appendFormatLine('<div class="vp-plot-name">{0}</div>', this.plotKindLang[kind]);
+            sbTagString.appendLine('</div>');
+        });
+        sbTagString.appendLine('</div>');
+        accBoxRequire.appendContent(sbTagString.toString());
+
+        var tblLayoutRequire = this.createVERSimpleLayout("15%");
+        tblLayoutRequire.addClass('vp-plot-setting-table');
+
+        sbTagString.clear();
+        sbTagString.appendFormatLine('<input type="text" class="vp-input" id="{0}"/>', 'x');
+        sbTagString.appendFormatLine('<input type="button" class="vp-select-data"  data-axes="{0}" value="{1}"/>'
+                                    , 'x', 'Select');
+        tblLayoutRequire.addReqRow('X Value', sbTagString.toString());
+
+        sbTagString.clear();
+        sbTagString.appendFormatLine('<input type="text" class="vp-input" id="{0}"/>', 'y');
+        sbTagString.appendFormatLine('<input type="button" class="vp-select-data"  data-axes="{0}" value="{1}"/>'
+                                    , 'y', 'Select');
+        tblLayoutRequire.addReqRow('Y Value', sbTagString.toString());
+
+        sbTagString.clear();
+        sbTagString.appendFormatLine('<input type="text" class="vp-input" id="{0}" placeholder="{1}"/>'
+                                    , 'z', '[[2-dimension]]');
+        tblLayoutRequire.addReqRow('Z Value', sbTagString.toString());
+
+        sbTagString.clear();
+        sbTagString.appendFormatLine('<input type="text" class="vp-input" id="{0}" value="10"/>', 'bins');
+        tblLayoutRequire.addReqRow('Bins', sbTagString.toString());
+
+        sbTagString.clear();
+        sbTagString.appendFormatLine('<input type="text" class="vp-input" id="{0}" placeholder="{1}"/>'
+                                    , 'extent', '[xmin, xmax, ymin, ymax]');
+        tblLayoutRequire.addRow('X, Y Extent', sbTagString.toString());
+
+        sbTagString.clear();
+        sbTagString.appendFormatLine('<input type="text" class="vp-input" id="{0}" value="{1}"/>'
+                                    , 'origin', 'lower');
+        tblLayoutRequire.addRow('Origin', sbTagString.toString());
+
+        sbTagString.clear();
+        sbTagString.appendFormatLine('<select id="{0}" class="{1}"></select>', 'cmap', 'vp-select');
+        sbTagString.appendFormatLine('<div class="{0}">', 'vp-plot-cmap-wrapper');
+        sbTagString.appendFormatLine('<div id="{0}", class="{1}">', 'vp_plotCmap', 'vp-plot-cmap');
+        sbTagString.appendFormatLine('<span id="{0}" class="{1}" data-caption-id="{2}">{3}</span>'
+                                    , 'vp_selectedCmap', 'vp-multilang', 'nothing_selected', 'none');
+        sbTagString.appendLine('</div>');
+        sbTagString.appendFormatLine('<div id="{0}" class="{1}"></div>', 'vp_plotCmapSelector', 'vp-plot-cmap-selector');
+        sbTagString.appendLine('</div>');
+        tblLayoutRequire.addRow('Color Map', sbTagString.toString());
+
+        sbTagString.clear();
+        sbTagString.appendFormatLine('<input type="text" class="vp-input" id="{0}"/>', 'label');
+        tblLayoutRequire.addRow('Chart Label', sbTagString.toString());
+
+        sbTagString.clear();
+        sbTagString.appendFormatLine('<input type="checkbox" class="vp-input" id="{0}"/>', 'useColor');
+        sbTagString.appendFormatLine('<label for="{0}">{1}</label><br/>', 'useColor', 'use color');
+        sbTagString.appendFormatLine('<input type="color" class="vp-input" id="{0}"/>', 'color');
+        tblLayoutRequire.addRow('Color', sbTagString.toString());
+
+        sbTagString.clear();
+        sbTagString.appendFormatLine('<select id="{0}" class="{1}">', 'markerSelector', 'vp-select option-select');
+        Object.keys(this.marker).forEach(id => {
+            var mark = this.marker[id];
+            sbTagString.appendFormatLine('<option value="{0}" data-img="{1}" data-caption-id="{2}">{3}</option>'
+                                        , mark.value, mark.img, id, mark.label);
+        });
+        sbTagString.appendLine('</select>');
+        sbTagString.appendFormatLine('<br/><input type="text" id="{0}" class="vp-input"/>', 'marker');
+        tblLayoutRequire.addRow('Marker', sbTagString.toString());
+
+        sbTagString.clear();
+        sbTagString.appendFormatLine('<select id="{0}" class="{1}">', 'linestyle', 'vp-select option-select');
+        sbTagString.appendFormatLine('<option value="{0}">{1}</option>', '-', 'solid');
+        sbTagString.appendFormatLine('<option value="{0}">{1}</option>', '--', 'dashed');
+        sbTagString.appendFormatLine('<option value="{0}">{1}</option>', ':', 'dotted');
+        sbTagString.appendFormatLine('<option value="{0}">{1}</option>', '-.', 'dash-dot');
+        sbTagString.appendLine('</select>');
+        tblLayoutRequire.addRow('Line Style', sbTagString.toString());
+
+        sbTagString.clear();
+        sbTagString.appendFormatLine('<input id="{0}" type="text" class="vp-input" placeholder="{1}"/>'
+                                    , 'vp_userOption', 'key=value, key=value ...');
+        tblLayoutRequire.addRow('User Option', sbTagString.toString());
+
+        // 박스에 추가
+        accBoxRequire.appendContent(tblLayoutRequire.toTagString());
+        sbPageContent.appendLine(accBoxRequire.toTagString());
+
+        // Box 2. Additional Options
+        var tblAdditional = this.createVERSimpleLayout("15%");
+        var accBoxAdditional = this.createOptionContainer('Additional Options');
+        sbTagString.clear();
+        sbTagString.appendFormatLine('<input type="text" class="vp-input" id="{0}"/>', 'title');
+        tblAdditional.addRow('Title', sbTagString.toString());
+
+        sbTagString.clear();
+        sbTagString.appendFormatLine('<input type="text" class="vp-input" id="{0}"/>', 'xlabel');
+        tblAdditional.addRow('X Label', sbTagString.toString());
+
+        sbTagString.clear();
+        sbTagString.appendFormatLine('<input type="text" class="vp-input" id="{0}"/>', 'ylabel');
+        tblAdditional.addRow('Y Label', sbTagString.toString());
+
+        sbTagString.clear();
+        sbTagString.appendFormatLine('<input type="text" class="vp-input" id="{0}" placeholder="{1}"/>'
+                                    , 'xlimit', '(min, max)');
+        tblAdditional.addRow('X Limit', sbTagString.toString());
+
+        sbTagString.clear();
+        sbTagString.appendFormatLine('<input type="text" class="vp-input" id="{0}" placeholder="{1}"/>'
+                                    , 'ylimit', '(min, max)');
+        tblAdditional.addRow('Y Limit', sbTagString.toString());
+
+        tblAdditional.addRow('', '<hr style="margin:0"/>');
+
+        sbTagString.clear();
+        sbTagString.appendFormatLine('<input type="text" class="vp-input" id="{0}"/>', 'legendTitle');
+        tblAdditional.addRow('Legend Title', sbTagString.toString());
+
+        sbTagString.clear();
+        sbTagString.appendFormatLine('<input type="text" class="vp-input" id="{0}"/>', 'legendLabel');
+        tblAdditional.addRow('Legend Labels', sbTagString.toString());
+
+        sbTagString.clear();
+        sbTagString.appendFormatLine('<select class="vp-select" id="{0}">', 'legendLoc');
+        this.legendPosition.forEach(pos => {
+            sbTagString.appendFormatLine('<option value="{0}">{1}</option>', pos, pos);
+        });
+        sbTagString.appendFormatLine('<option value="{0}">{1}</option>', 'center', 'center');
+        sbTagString.appendLine('</select>')
+        tblAdditional.addRow('Legend Position', sbTagString.toString());
+
+        tblAdditional.addRow('', '<hr style="margin:0"/>');
+
+        sbTagString.clear();
+        sbTagString.appendFormatLine('<input type="text" class="vp-input" id="{0}" placeholder="{1}"/>'
+                                    , 'savefigpath', 'file.png' );
+        sbTagString.appendFormatLine('<div id="{0}" class="{1}"></div>', 'vp_openFileNavigationBtn', 'vp-file-browser-button');
+        tblAdditional.addRow('Save Figure', sbTagString.toString());
+
+        // 박스에 추가
+        accBoxAdditional.appendContent(tblAdditional.toTagString());
+        sbPageContent.appendLine(accBoxAdditional.toTagString());
+
+
+        // postfix code 입력 영역
+        sbPageContent.appendLine(this.createPostfixCode());
+
+        this.setPage(sbPageContent.toString());
+
         
         // 차트 서브플롯 페이지 구성
         this.bindSubplotOption1();
@@ -277,7 +492,7 @@ define([
             if (package == undefined) package = that.plotPackage['plot'];
 
             // 모두 숨기기 (단, 대상 변수 입력란과 차트 유형 선택지 제외)
-            $(that.wrapSelector('#vp_plotSetting table tr:gt(1):not(:last)')).hide();
+            $(that.wrapSelector('table.vp-plot-setting-table tr:not(:last)')).hide();
 
             // 해당 옵션에 있는 선택지만 보이게 처리
             package.input && package.input.forEach(obj => {
@@ -285,10 +500,13 @@ define([
 
                 var label = obj.label;
                 if (label != undefined) {
+                    $(that.wrapSelector('#' + obj.name)).closest('tr').find('th').removeClass(vpConst.COLOR_FONT_ORANGE);
                     if (obj.required != false) {
-                        label = "* " + obj.label;
+                        // label = "* " + obj.label;
+                        $(that.wrapSelector('#' + obj.name)).closest('tr').find('th').addClass(vpConst.COLOR_FONT_ORANGE);
                     }
-                    $(that.wrapSelector("label[for='" + obj.name + "']")).text(label);
+                    // $(that.wrapSelector("label[for='" + obj.name + "']")).text(label);
+                    $(that.wrapSelector('#' + obj.name)).closest('tr').find('th').text(label);
                 }
             });
             package.variable && package.variable.forEach(obj => {
@@ -302,17 +520,20 @@ define([
         // 플롯 차트 옵션으로 초기화
         var plotPackage = { ...this.plotPackage[plotType] };
         // 모두 숨기기 (단, 대상 변수 입력란과 차트 유형 선택지 제외)
-        $(this.wrapSelector('#vp_plotSetting table tr:gt(1):not(:last)')).hide();
+        $(this.wrapSelector('table.vp-plot-setting-table tr:not(:last)')).hide();
 
         // 해당 옵션에 있는 선택지만 보이게 처리
         plotPackage.input && plotPackage.input.forEach(obj => {
             $(this.wrapSelector('#' + obj.name)).closest('tr').show();
             var label = obj.label;
             if (label != undefined) {
+                $(this.wrapSelector('#' + obj.name)).closest('tr').find('th').removeClass(vpConst.COLOR_FONT_ORANGE);
                 if (obj.required != false) {
-                    label = "* " + obj.label;
+                    // label = "* " + obj.label;
+                    $(this.wrapSelector('#' + obj.name)).closest('tr').find('th').addClass(vpConst.COLOR_FONT_ORANGE);
                 }
-                $(this.wrapSelector("label[for='" + obj.name + "']")).text(label);
+                // $(this.wrapSelector("label[for='" + obj.name + "']")).text(label);
+                $(this.wrapSelector('#' + obj.name)).closest('tr').find('th').text(label);
             }
         });
         plotPackage.variable && plotPackage.variable.forEach(obj => {
@@ -765,7 +986,7 @@ define([
             var sbCode = new sb.StringBuilder();
 
             // add prefix code
-            var prefixCode = $(this.wrapSelector('#vp_prefixBox textarea')).val();
+            var prefixCode = this.getPrefixCode();
             if (prefixCode.length > 0) {
                 sbCode.appendLine(prefixCode);
             }
@@ -832,7 +1053,7 @@ define([
             sbCode.append('plt.show()');
 
             // add postfix code
-            var postfix = $(this.wrapSelector('#vp_postfixBox textarea')).val();
+            var postfix = this.getPostfixCode();
             if (postfix.length > 0) {
                 sbCode.appendLine('');
                 sbCode.append(postfix);
@@ -883,18 +1104,18 @@ define([
                     {
                         name: 'kind',
                         type: 'var',
-                        label: 'chart type'
+                        label: 'Chart Type'
                     },
                     {
                         name: 'x',
                         type: 'var',
-                        label: 'x data',
+                        label: 'X Value',
                         required: false
                     },
                     {
                         name: 'y',
                         type: 'var',
-                        label: 'y data'
+                        label: 'Y Value'
                     }
                 ],
                 variable: [
@@ -931,17 +1152,17 @@ define([
                     {
                         name: 'kind',
                         type: 'var',
-                        label: 'chart type'
+                        label: 'Chart Type'
                     },
                     {
                         name: 'x',
                         type: 'var',
-                        label: 'x'
+                        label: 'X Value'
                     },
                     {
                         name: 'y',
                         type: 'var',
-                        label: 'height'
+                        label: 'Height'
                     }
                 ],
                 variable: [
@@ -974,17 +1195,17 @@ define([
                     {
                         name: 'kind',
                         type: 'var',
-                        label: 'chart type'
+                        label: 'Chart Type'
                     },
                     {
                         name: 'x',
                         type: 'var',
-                        label: 'y'
+                        label: 'Y Value'
                     },
                     {
                         name: 'y',
                         type: 'var',
-                        label: 'width'
+                        label: 'Width'
                     }
                 ],
                 variable: [
@@ -1017,12 +1238,12 @@ define([
                     {
                         name: 'kind',
                         type: 'var',
-                        label: 'chart type'
+                        label: 'Chart Type'
                     },
                     {
                         name: 'x',
                         type: 'var',
-                        label: 'data'
+                        label: 'Value'
                     }
                 ],
                 variable: [
@@ -1061,17 +1282,17 @@ define([
                     {
                         name: 'kind',
                         type: 'var',
-                        label: 'chart type'
+                        label: 'Chart Type'
                     },
                     {
                         name: 'x',
                         type: 'var',
-                        label: 'x data'
+                        label: 'X Value'
                     },
                     {
                         name: 'y',
                         type: 'var',
-                        label: 'y data'
+                        label: 'Y Value'
                     }
                 ],
                 variable: [
@@ -1089,17 +1310,17 @@ define([
                     {
                         name: 'kind',
                         type: 'var',
-                        label: 'chart type'
+                        label: 'Chart Type'
                     },
                     {
                         name: 'x',
                         type: 'var',
-                        label: 'x data'
+                        label: 'X Value'
                     },
                     {
                         name: 'y',
                         type: 'var',
-                        label: 'y data'
+                        label: 'Y Value'
                     }
                 ],
                 variable: [
@@ -1129,12 +1350,12 @@ define([
                     {
                         name: 'kind',
                         type: 'var',
-                        label: 'chart type'
+                        label: 'Chart Type'
                     },
                     {
                         name: 'x',
                         type: 'var',
-                        label: 'data'
+                        label: 'Value'
                     }
                 ],
                 variable: [
@@ -1152,17 +1373,17 @@ define([
                     {
                         name: 'kind',
                         type: 'var',
-                        label: 'chart type'
+                        label: 'Chart Type'
                     },
                     {
                         name: 'x',
                         type: 'var',
-                        label: 'x data'
+                        label: 'X Value'
                     },
                     {
                         name: 'y',
                         type: 'var',
-                        label: 'y data'
+                        label: 'Y Value'
                     }
                 ],
                 variable: [
@@ -1189,17 +1410,17 @@ define([
                     {
                         name: 'kind',
                         type: 'var',
-                        label: 'chart type'
+                        label: 'Chart Type'
                     },
                     {
                         name: 'x',
                         type: 'var',
-                        label: 'x data'
+                        label: 'X Value'
                     },
                     {
                         name: 'y',
                         type: 'var',
-                        label: 'y data'
+                        label: 'Y Value'
                     }
                 ],
                 variable: [
@@ -1226,22 +1447,22 @@ define([
                     {
                         name: 'kind',
                         type: 'var',
-                        label: 'chart type'
+                        label: 'Chart Type'
                     },
                     {
                         name: 'x',
                         type: 'var',
-                        label: 'x data'
+                        label: 'X Value'
                     },
                     {
                         name: 'y',
                         type: 'var',
-                        label: 'y data'
+                        label: 'Y Value'
                     },
                     {
                         name: 'z',
                         type: 'var',
-                        label: 'z data'
+                        label: 'Z Value'
                     }
                 ],
                 variable: [
@@ -1267,12 +1488,12 @@ define([
                     {
                         name: 'kind',
                         type: 'var',
-                        label: 'chart type'
+                        label: 'Chart Type'
                     },
                     {
                         name: 'z',
                         type: 'var',
-                        label: 'z data'
+                        label: 'Value'
                     }
                 ],
                 variable: [
@@ -1302,17 +1523,17 @@ define([
                     {
                         name: 'kind',
                         type: 'var',
-                        label: 'chart type'
+                        label: 'Chart Type'
                     },
                     {
                         name: 'x',
                         type: 'var',
-                        label: 'x data'
+                        label: 'X Value'
                     },
                     {
                         name: 'y',
                         type: 'var',
-                        label: 'y data'
+                        label: 'Y Value'
                     }
                 ]
             }
@@ -1463,24 +1684,56 @@ define([
             'pie', 'scatter', 'hexbin', 'contour', 'imshow', 'errorbar'
         ];
         this.plotKindLang = {
-            'plot': '플롯',
-            'bar': '바 차트',
-            'barh': '가로 바',
-            'hist': '히스토그램',
-            'boxplot': '박스 플롯',
-            'stackplot': '스택 플롯',
-            'pie': '파이 차트',
-            'scatter': '스캐터 플롯',
-            'hexbin': '헥스빈 플롯',
-            'contour': '컨투어 플롯',
-            'imshow': '이미지 플롯',
-            'errorbar': '오차 막대'
+            'plot': 'Line',
+            'bar': 'Bar',
+            'barh': 'Bar(horizon)',
+            'hist': 'Histogram',
+            'boxplot': 'Box Plot',
+            'stackplot': 'Stack Plot',
+            'pie': 'Pie Chart',
+            'scatter': 'Scatter Plot',
+            'hexbin': 'Hexbin Plot',
+            'contour': 'Contour Plot',
+            'imshow': 'Image Plot',
+            'errorbar': 'Error Bar'
         };
         // cmap 종류
         this.cmap = [
             '', 'viridis', 'plasma', 'inferno', 'magma', 'cividis'
             , 'Pastel1', 'Pastel2', 'Paired', 'Accent', 'Dark2', 'Set1', 'Set2', 'Set3', 'tab10', 'tab20', 'tab20b', 'tab20c'
         ];
+        // marker 종류
+        this.marker = {
+            'custom': { label: 'Custom', value: 'marker' },
+            'point' : { label: '.', value: '.', img: 'm00.png' }, 
+            'pixel' : { label: ',', value: ',', img: 'm01.png' }, 
+            'circle' : { label: 'o', value: 'o', img: 'm02.png' }, 
+            'triangle_down' : { label: '▼', value: 'v', img: 'm03.png' }, 
+            'triangle_up' : { label: '▲', value: '^', img: 'm04.png' }, 
+            'triangle_left' : { label: '◀', value: '<', img: 'm05.png' }, 
+            'triangle_right' : { label: '▶', value: '>', img: 'm06.png' }, 
+            'tri_down' : { label: '┬', value: '1', img: 'm07.png' }, 
+            'tri_up' : { label: '┵', value: '2', img: 'm08.png' }, 
+            'tri_left' : { label: '┤', value: '3', img: 'm09.png' }, 
+            'tri_right' : { label: '├', value: '4', img: 'm10.png' }, 
+            'octagon' : { label: 'octagon', value: '8', img: 'm11.png' }, 
+            'square' : { label: 'square', value: 's', img: 'm12.png' }, 
+            'pentagon' : { label: 'pentagon', value: 'p', img: 'm13.png' }, 
+            'plus (filled)' : { label: 'filled plus', value: 'P', img: 'm23.png' }, 
+            'star' : { label: 'star', value: '*', img: 'm14.png' }, 
+            'hexagon1' : { label: 'hexagon1', value: 'h', img: 'm15.png' }, 
+            'hexagon2' : { label: 'hexagon2', value: 'H', img: 'm16.png' }, 
+            'plus' : { label: 'plus', value: '+', img: 'm17.png' }, 
+            'x' : { label: 'x', value: 'x', img: 'm18.png' }, 
+            'x (filled)' : { label: 'filled x', value: 'X', img: 'm24.png' }, 
+            'diamond' : { label: 'diamond', value: 'D', img: 'm19.png' }, 
+            'thin_diamond' : { label: 'thin diamond', value: 'd', img: 'm20.png' }
+        }
+        // 범례 위치
+        this.legendPosition = [
+            'best', 'upper right', 'upper left', 'lower left', 'lower right',
+            'center left', 'center right', 'lower center', 'upper center', 'center'
+        ];
         this.methodList = {
             'categorical': [
                 { label: 'count', method: 'count()' },
