@@ -98,13 +98,14 @@ define([
         var tblInput = document.createElement('td');
 
         var lbl = document.createElement('label');
+        var requiredFontStyle = required? vpConst.COLOR_FONT_ORANGE : '';
         $(lbl).attr({
-            'for': obj.name
+            'for': obj.name,
+            'class': requiredFontStyle
         });
-        lbl.innerText = (required? '* ':'') + obj.label + (showKey?' ('+obj.name+')':'');
+        // lbl.innerText = (required? '* ':'') + obj.label + (showKey?' ('+obj.name+')':'');
+        lbl.innerText = obj.label + (showKey?' ('+obj.name+')':'');
         tblLabel.appendChild(lbl);
-        // tblInput.appendChild(document.createElement('br'));
-
 
         // 명시된 component에 맞는 태그 구성해서 붙여주기
         switch (obj.component) {
@@ -275,16 +276,22 @@ define([
 
     /**
      * types에 해당하는 데이터유형을 가진 변수 목록 조회
-     * @param {*} types 조회할 변수들의 데이터유형 목록
-     * @param {*} callback 조회 후 실행할 callback. parameter로 result를 받는다
+     * @param {Array} types 조회할 변수들의 데이터유형 목록
+     * @param {Function} callback 조회 후 실행할 callback. parameter로 result를 받는다
      */
     var vp_searchVarList = function(types, callback) {
         // types에 맞는 변수목록 조회하는 명령문 구성
         var cmdSB = new sb.StringBuilder();
-        cmdSB.append(`print([{'varName': v, 'varType': type(eval(v)).__name__}`);
-        cmdSB.appendFormat(`for v in dir() if (v not in {0}) `, JSON.stringify(_VP_NOT_USING_VAR));
-        cmdSB.appendFormat(`& (type(eval(v)).__name__ not in {0}) `, JSON.stringify(_VP_NOT_USING_TYPE));
-        cmdSB.appendFormat(`& (type(eval(v)).__name__ in {0})])`, JSON.stringify(types));
+        cmdSB.appendLine('import json');
+        cmdSB.append(`print(json.dumps([{'varName': v, 'varType': type(eval(v)).__name__}`);
+        cmdSB.append(`for v in dir() if (not v.startswith('_')) `);
+        if (types != undefined && types.length > 0) {
+            cmdSB.appendFormat(`& (type(eval(v)).__name__ in {0})`, JSON.stringify(types));
+        } else {
+            cmdSB.appendFormat('& (v not in {0})', JSON.stringify(_VP_NOT_USING_VAR));
+            cmdSB.appendFormat(`& (type(eval(v)).__name__ not in {0}) `, JSON.stringify(_VP_NOT_USING_TYPE));
+        }
+        cmdSB.append(']))');
 
         // FIXME: vpFuncJS에만 kernel 사용하는 메서드가 정의되어 있어서 임시로 사용
         vp_executePython(cmdSB.toString(), function(result) {
@@ -442,19 +449,19 @@ define([
                 var id = '${' + v.name + '}';
                 if (val == undefined || val == ''){
                     if (v.required == undefined || v.required == true) {
-                        throw new Error(v.label+'에 값을 입력해주세요.');
+                        // throw new Error(v.label+'에 값을 입력해주세요.');
+                        throw new Error("'" + v.label + "' is required.");
                     }
                     // 값이 없을 경우 빈 값으로 파라미터 대체
                     code = code.split(id).join('');
                 } else {
-                    // TODO: Cell MD
-                    // _VP_CODEMD.input[i].value = val;
-                    // val type 에 따라 다른 형식 적용
+                    // Deprecated: val type 에 따라 다른 형식 적용
                     if (v.type == 'text') {
                         val = "'"+val+"'";
-                    } else if (v.type == 'list') {
-                        val = '['+val+']';
-                    }
+                    } 
+                    // else if (v.type == 'list') {
+                    //     val = '['+val+']';
+                    // }
                     code = code.split(id).join(val);
                 }
             });
@@ -467,18 +474,18 @@ define([
                 // 값이 입력되지 않았을 경우, 필수 표시가 되어있으면 알림
                 if (val == undefined || val == ''){
                     if (v.required == true) {
-                        throw new Error(v.label+'에 값을 입력해주세요.');
+                        // throw new Error(v.label+'에 값을 입력해주세요.');
+                        throw new Error("'" + v.label + "' is required.");
                     }
                 }
                 else {
-                    // TODO: Cell MD
-                    // _VP_CODEMD.variable[i].value = val;
-                    // val type 에 따라 다른 형식 적용
+                    // Deprecated: val type 에 따라 다른 형식 적용
                     if (v.type == 'text') {
                         val = "'"+val+"'";
-                    } else if (v.type == 'list') {
-                        val = '['+val+']';
                     }
+                    //  else if (v.type == 'list') {
+                    //     val = '['+val+']';
+                    // }
                     opt_params += ', '+v.name+'='+val;
                 }
             })
@@ -491,7 +498,8 @@ define([
                 var id = '${' + v.name + '}'
                 if (val == undefined || val == ''){
                     if (v.required == true) {
-                        throw new Error(v.label+'에 값을 입력해주세요.');
+                        // throw new Error(v.label+'에 값을 입력해주세요.');
+                        throw new Error("'" + v.label + "' is required.");
                     } else {
                         // 출력 변수 없을 경우 공백으로 만들기
                         code = code.split(id).join('');
@@ -500,12 +508,13 @@ define([
                 } else {
                     // TODO: Cell MD
                     // _VP_CODEMD.output[i].value = val;
-                    // val type 에 따라 다른 형식 적용
+                    // Deprecated: val type 에 따라 다른 형식 적용
                     if (v.type == 'text') {
                         val = "'"+val+"'";
-                    } else if (v.type == 'list') {
-                        val = '['+val+']';
-                    }
+                    } 
+                    // else if (v.type == 'list') {
+                    //     val = '['+val+']';
+                    // }
                     code = code.split(id).join(val);
                 }
             });
@@ -590,6 +599,8 @@ define([
         vp_generateVarSelect: vp_generateVarSelect,
         vp_searchVarList: vp_searchVarList,
         vp_getTagValue: vp_getTagValue,
-        vp_bindColumnSource: vp_bindColumnSource
+        vp_bindColumnSource: vp_bindColumnSource,
+        _VP_NOT_USING_VAR: _VP_NOT_USING_VAR,
+        _VP_NOT_USING_TYPE: _VP_NOT_USING_TYPE
     };
 });
\ No newline at end of file
