@@ -7,7 +7,8 @@ define([
     , 'nbextensions/visualpython/src/common/vpFuncJS'
     , 'nbextensions/visualpython/src/common/vpMakeDom'
     , 'nbextensions/visualpython/src/pandas/common/pandasLibrary'
-], function(requirejs, $, vpCommon, vpConst, sb, vpFuncJS, vpMakeDom, libPandas) {
+    , 'nbextensions/visualpython/src/common/component/vpSuggestInputText'
+], function(requirejs, $, vpCommon, vpConst, sb, vpFuncJS, vpMakeDom, libPandas, vpSuggestInputText) {
 
     /**
      * 코드 실행 후 결과값 보여주기 여부
