@@ -5,9 +5,9 @@ define([
     , 'nbextensions/visualpython/src/common/vpMakeDom'
     , 'nbextensions/visualpython/src/common/StringBuilder'
     //
-    , 'nbextensions/visualpython/src/component/fileNavigation/api'
-    , 'nbextensions/visualpython/src/component/fileNavigation/executor'
-    , 'nbextensions/visualpython/src/component/fileNavigation/constData'
+    , 'nbextensions/visualpython/src/pandas/fileNavigation/api'
+    , 'nbextensions/visualpython/src/pandas/fileNavigation/executor'
+    , 'nbextensions/visualpython/src/pandas/fileNavigation/constData'
 ], function ( requirejs, $, vpCommon, vpMakeDom, sb,
               componentConstApi, executor, constData) {
 
@@ -54,11 +54,11 @@ define([
             /** 20201118 이진용 주임 수정 */
             /** 현재 디렉토리에 파일 저장 -> Save file to current directory */
             /** 파일 이름 입력 -> Input file name */
-            var saveFileDataBtn = $(`<button class='directoryComponent-btn-saveVisualPython'
+            var saveFileDataBtn = $(`<button class='fileNavigationPage-btn-saveVisualPython'
                                                  style='margin-left: 10px;'>Save file to current directory</button>`);
             var saveFileDataInput = $(`<input id='vp-fileNavigation' type='text' placeholder='Input file name'></input>`);
-            $('.directoryComponent-savebutton').append(saveFileDataInput);
-            $('.directoryComponent-savebutton').append(saveFileDataBtn);
+            $('.fileNavigationPage-savebutton').append(saveFileDataInput);
+            $('.fileNavigationPage-savebutton').append(saveFileDataBtn);
          
             controlToggleInput();
             $(saveFileDataInput).on('change keyup paste', function() {
@@ -89,37 +89,37 @@ define([
     }
 
     /** */
-    FileNavigationRenderer.prototype.renderCurrentDirPathInfo = function(dirInfoArr, rootFolderName) {
-        $('.directoryComponent-container').empty();
+    FileNavigationRenderer.prototype.renderCurrentDirPathInfo = function(dirInfoArr) {
+        $('.fileNavigationPage-directory-container').empty();
 
-        var currentDirRootDom = $(`<div class='directoryComponent-right scrollbar'>
+        var currentDirRootDom = $(`<div class='fileNavigationPage-right'>
                                   </div>`);
         var { folderArr } = this.makeFolderOrFileDomArr(dirInfoArr);
     
-        currentDirRootDom.appendTo('.directoryComponent-container');
-        var directoryComponentUl = $('.directoryComponent-ul');
+        currentDirRootDom.appendTo('.fileNavigationPage-directory-container');
+        var fileNavigationPageUl = $('.fileNavigationPage-ul');
         folderArr.forEach(dom => {
-            directoryComponentUl.append(dom);
+            fileNavigationPageUl.append(dom);
         });
     }
 
     /** */
-    FileNavigationRenderer.prototype.renderCurrentDirPathInfoRightBody = function(dirInfoArr, rootFolderName) {
-        $('.directoryComponent-right').empty();
-        var currentDirRootDom = $(`<div class='directoryComponent-body'></div>`);
+    FileNavigationRenderer.prototype.renderCurrentDirPathInfoRightBody = function(dirInfoArr) {
+        $('.fileNavigationPage-right').empty();
+        var currentDirRootDom = $(`<div class='fileNavigationPage-body'></div>`);
         var { folderArr, fileArr } = this.makeFolderOrFileDomArr(dirInfoArr);
         
-        var directoryComponentUl = $(`<ul class='directoryComponent-ul'>
+        var fileNavigationPageUl = $(`<ul class='fileNavigationPage-ul'>
                                       </ul>`);
   
         folderArr.forEach(dom => {
-            directoryComponentUl.append(dom);
+            fileNavigationPageUl.append(dom);
         });
         fileArr.forEach(dom => {
-            directoryComponentUl.append(dom);
+            fileNavigationPageUl.append(dom);
         });
-        currentDirRootDom.append(directoryComponentUl);
-        currentDirRootDom.appendTo('.directoryComponent-right');
+        currentDirRootDom.append(fileNavigationPageUl);
+        currentDirRootDom.appendTo('.fileNavigationPage-right');
     }
 
     /** <div/> 태그 형식의 폴더 디렉토리를 만드는 함수 */
@@ -129,12 +129,15 @@ define([
         var folderName = node.name;
         var folderPath = node.path;
 
-        var directoryLi = renderLi({class: 'directoryComponent-li'});
-        var directorySpan = renderSpan({class:'directoryComponent-column'});
-        var directorySpanDir = renderSpan({class:'directoryComponent-dir-text icon-folder'
-                                            ,text: `${folderName}`});
-  
-        $(directorySpanDir).click(function() {
+        var directoryLi = renderLi({class: 'fileNavigationPage-li'});
+        var directorySpan = renderSpan({class:'fileNavigationPage-column'});
+        var directoryI = $(`<i class="fileNavigationPage-dir-text 
+                                        item_icon 
+                                        folder_icon 
+                                        icon-fixed-width">
+                                ${folderName}
+                            </i>`);
+        $(directoryI).click(function() {
             var dirObj = {
                 direction: NAVIGATION_DIRECTION_TYPE.TO,
                 destDir: folderPath
@@ -142,7 +145,7 @@ define([
             executeKernelFromDirBody(dirObj, fileNavigationRendererThis);
         });
 
-        $(directoryLi).append($(directorySpan).append(directorySpanDir));
+        $(directoryLi).append($(directorySpan).append(directoryI));
         return directoryLi;
     }
 
@@ -152,11 +155,14 @@ define([
         var fileNavigationState = this.getFileNavigationState();
         var fileName = node.name;
 
-        var directoryLi = renderLi({class: 'directoryComponent-li'});
-        var directorySpan = renderSpan({class: 'directoryComponent-column directoryComponent-dir-text icon-file'
-                                       , text: `${fileName}`});
-
-        directorySpan.click(function() {
+        var directoryLi = renderLi({class: 'fileNavigationPage-li'});
+        var directoryI = $(`<i class="fileNavigationPage-dir-text 
+                                        item_icon 
+                                        file_icon 
+                                        icon-fixed-width">
+                                ${fileName}
+                            </i>`);
+        directoryI.click(function() {
             var dirPath = that.makeNewCurrRelativePath();
             var dataOption = fileNavigationState.getFileOptionData();
             if (fileName.indexOf('.' + dataOption.fileExtension) === -1) {
@@ -167,7 +173,7 @@ define([
             that.selectFile(dirPath, fileName);
         });
 
-        directoryLi.append(directorySpan);
+        directoryLi.append(directoryI);
         return directoryLi;
     }
 
@@ -245,8 +251,8 @@ define([
 
     // loadingBar를 생성합니다.
     FileNavigationRenderer.prototype.startLoadingBar = function() {
-        $('.directoryComponent-container').empty();
-        this.renderLoadingBar();
+        // $('.fileNavigationPage-directory-container').empty();
+        // this.renderLoadingBar();
     }
 
     // loadingBar를 종료합니다.
@@ -255,12 +261,12 @@ define([
         fileNavigationRendererThis.fileNavigationState.setRelativeDir(currentRelativePathStr);
         fileNavigationRendererThis.fileNavigationState.setCurrentDir(currentDirStr);
 
-        $('.directoryComponent-container').find('#vp_loadingBar').remove();
+        // $('.fileNavigationPage-directory-container').find('#vp_loadingBar').remove();
     }
 
     // 로딩을 생성하는 함수
     FileNavigationRenderer.prototype.renderLoadingBar = function() {
-        vpCommon.renderLoadingBar();
+        // vpCommon.renderLoadingBar();
     }
 
     /** */
@@ -321,8 +327,8 @@ define([
             nestedLength += pathToken.length + 1;
         });
              
-        $('.directoryComponent-directory-nowLocation').empty();
-        $('.directoryComponent-directory-nowLocation').append(currentRelativePathDomElement);
+        $('.fileNavigationPage-directory-nowLocation').empty();
+        $('.fileNavigationPage-directory-nowLocation').append(currentRelativePathDomElement);
     }
 
     FileNavigationRenderer.prototype.selectFile = function(relativeDirPath, filePathStr) {
@@ -388,7 +394,9 @@ define([
         /** 최초의 path가 C:/Users/L.E.E/Desktop/Bit Python이라면, baseFolder는 Bit Python
          *  현재 이동한 시점의 path에서 baseFolder인 Bit Python가 존재하지 않을 때
          */
-        if (upDirectoryCount > 0 && currentDirStr.indexOf(baseFolder) === -1) {
+        if (upDirectoryCount > 0 
+            && currentDirStr.indexOf(baseFolder) === -1) {
+            /** 2020년 12월 21일 single quote 삭제 */
             $(fileNavigationRendererThis.fileResultState.pathInputId).val(`${prefixUpDirectory}${relativeDirPath}${slashstr}${filePathStr}`);
             $(fileNavigationRendererThis.fileResultState.fileInputId).val(`${filePathStr}`);
         /** 현재 이동한 시점의 path에서 baseFolder인 Bit Python가 존재할 때 */
@@ -396,8 +404,9 @@ define([
             $(fileNavigationRendererThis.fileResultState.pathInputId).val(`./${relativeDirPath}${slashstr}${filePathStr}`);
             $(fileNavigationRendererThis.fileResultState.fileInputId).val(`${filePathStr}`);
         }
-
-        vpCommon.renderSuccessMessage(`${filePathStr} selection completed`);
+        
+        // vpCommon.renderSuccessMessage(filePathStr + ' selection ' + 'completed');
+        
         /** 장안태 추가. 파일 선택 완료시 문서 이벤트 발동 */
         if (fileNavigationState.getFileNavigationtype() === 'SAVE_FILE') {
             $(document).trigger({
