@@ -70,6 +70,7 @@ define([
         }
         this.package = {
             input: [
+                { name: 'vp_pyReturn' },
                 { name: 'vp_pyFloat' }
             ]
         }
@@ -109,6 +110,10 @@ define([
         sbTagString.appendFormat('<input type="text" id="{0}" class="{1}" />', 'vp_pyFloat', 'vp-input');
         tblLayoutRequire.addRow("Input Data", sbTagString.toString());
 
+        sbTagString.clear();
+        sbTagString.appendFormat('<input type="text" id="{0}" class="{1}" />', 'vp_pyReturn', 'vp-input l');
+        tblLayoutRequire.addRow("Return Variable", sbTagString.toString());
+        
         // 필수 옵션 영역 (아코디언 박스)
         var accBoxRequire = this.createOptionContainer(vpConst.API_REQUIRE_OPTION_BOX_CAPTION);
         accBoxRequire.setOpenBox(true);
@@ -144,6 +149,10 @@ define([
         if (prefixCode != '') {
             code.appendLine(prefixCode);
         }
+        var returnVar = $(this.wrapSelector('#vp_pyReturn')).val();
+        if (returnVar != '') {
+            code.appendFormat("{0} = ", returnVar);
+        }
         code.appendFormat('float({0})', $(this.wrapSelector('#vp_pyFloat')).val());
         var postfixCode = this.getPostfixCode();
         if (postfixCode != '') {
